/*****************************************************************************
 *  Rohde&Schwarz SMxV Signal Generator
 *
 *  Original Release: April 2020
 *  By: Martin Krcmar
 *
 *  Should you have any technical questions please contact the hotline of
 *  Rohde & Schwarz Vertriebs-GmbH Rohde & Schwarz Support Center
 *
 *  e-mail: CustomerSupport@rohde-schwarz.com
 *
 *  Modification History:
 *     see ChangeLog
 *
 *****************************************************************************/

#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include "rssmxv.h"
#include "rssmxv_utility.h"

#if (defined(WIN32) || defined(_WIN32) || defined(__WIN32__) || defined(__NT__))
#define ANSI
#endif
#ifndef ANSI /* UNIX compatible */
#include <sys/timeb.h>
#include <sys/types.h>
#include <unistd.h>
#define Sleep sleep
#else /* ANSI compatible */
#include <Windows.h>
#endif
#if defined(_CVI_)
#include <utility.h>
#endif

/*****************************************************************************
 *- Value Definition and Range Tables ---------------------------------------*
 *****************************************************************************/

/*****************************************************************************
 *- Callback Declarations ---------------------------------------------------*
 *****************************************************************************/

/*****************************************************************************
 *- User-Callable Functions (Exportable Functions) --------------------------*
 *****************************************************************************/

/*****************************************************************************
 * Function: rssmxv_init
 * Purpose:  VXIplug&play required function. Calls the
 *           rssmxv_InitWithOptions function.
 *****************************************************************************/

ViStatus _VI_FUNC rssmxv_init(ViRsrc resourceName, ViBoolean IDQuery,
                              ViBoolean resetDevice, ViSession* newInstrSession)
{
    ViStatus error = VI_SUCCESS;

    if (newInstrSession == NULL)
    {
        (void)RsCore_SetErrorInfo(0, VI_FALSE, RS_ERROR_INVALID_PARAMETER,
                                  VI_ERROR_PARAMETER4, "Null address for Instrument Handle");

        checkErr(RS_ERROR_INVALID_PARAMETER);
    }

    checkErr(rssmxv_InitWithOptions(resourceName, IDQuery, resetDevice, "", newInstrSession));

Error:
    return error;
}

/*****************************************************************************
 * Function: rssmxv_InitWithOptions
 * Purpose:  This function creates a new RS session and calls the
 *           RsInit function.
 *****************************************************************************/
ViStatus _VI_FUNC rssmxv_InitWithOptions(
    ViRsrc resourceName,
    ViBoolean IDQuery,
    ViBoolean resetDevice,
    ViString optionString,
    ViSession* newInstrSession)
{
    ViStatus error = VI_SUCCESS;
    RsCoreAttributePtr* attrList = NULL;
    ViSession instrSession = 0;
    RsCoreSessionPtr sessionProperties = NULL;

    if (newInstrSession == NULL)
    {
        (void)RsCore_SetErrorInfo(0, VI_FALSE, RS_ERROR_INVALID_PARAMETER, VI_ERROR_PARAMETER5,
                                  "Null address for Instrument Handle");
        checkErr(RS_ERROR_INVALID_PARAMETER);
    }

    attrList = (RsCoreAttributePtr *)rssmxv_RsCoreAttributeList;

    *newInstrSession = 0;

    checkErr(RsCore_NewSpecificDriver(
        resourceName, // VISA Resource Name
        "rssmxv", // driver prefix
        optionString, // Init Options string, is applied to the session settings
        attrList, // List of all attributes from the rsxxx_AttrPropertiesList
        rssmxv_RsCoreAttributeListLength, // Length of attributes list
        VI_FALSE,
        // idnModelFullName Model has the full *IDN? query name e.g. true: "SMCV100B", VI_FALSE: "SMXV" Used in CheckInstrument()
        0, // WriteDelay
        0, // ReadDelay
        1000000, // IO Segment Size
        RS_VAL_OPCWAIT_STBPOLLING, // OPC Wait Mode
        RSSMXV_OPC_TIMEOUT, // OPC timeout
        10000, // VISA Timeout
        600000, // Self-test timeout
        RS_VAL_BIN_FLOAT_FORMAT_SINGLE_4BYTES, // BinaryFloatNumbersFormat
        RS_VAL_BIN_INTEGER_FORMAT_INT32_4BYTES, // binaryIntegerNumbersFormat
        &instrSession));

    // Minimal allowed rscore version is 4.5.0
    checkErr(RsCore_CheckMinimalEngineVersion(instrSession, 4, 5, 0));

    checkErr(RsCore_GetRsSession(instrSession, &sessionProperties));

    // No SCPI command has been sent yet.
    // Call viClear before sending any SCPI command
    checkErr(RsCore_ViClear(instrSession));

    /* --- Here perform settings that are default for this driver,
    but can be overwritten by the optionsString settings */

    sessionProperties->autoSystErrQuery = VI_FALSE;

    // Parse option string and optionally sets the initial state of the following session attributes
    checkErr(RsCore_ApplyOptionString(instrSession, optionString));
    checkErr(RsCore_BuildRepCapTable(instrSession, rssmxv_RsCoreRepCapTable, rssmxv_RsCoreRepCapTableCount));

    // Query *IDN? string, parse it and set the following attributes:
    // -RS_ATTR_INSTRUMENT_MANUFACTURER
    // - RS_ATTR_INSTRUMENT_MODEL - based on the idnModelFullName true: "SMCV100B", false : "SMXV"
    // - RS_ATTR_INSTRUMENT_FIRMWARE_REVISION
    checkErr(
        RsCore_QueryAndParseIDNstringWithAliases(instrSession, RSSMXV_SIMULATION_ID_QUERY, NULL, NULL, NULL));

    // Query *OPT? string, parse the options, remove the duplicates, sort them and store the result string to RS_ATTR_OPTIONS_LIST
    checkErr(RsCore_QueryAndParseOPTstring(instrSession, RSSMXV_SIMULATION_OPT_QUERY, RS_VAL_OPTIONS_PARSING_AUTO));

    // Default Instrument Setup + optional *RST
    if (resetDevice == VI_TRUE)
    {
        checkErr(rssmxv_reset(instrSession));
    }
    else
    {
        checkErr(rssmxv_DefaultInstrSetup(instrSession));
    }

    if (IDQuery == VI_TRUE)
    {
        checkErr(RsCore_FitsIDNpattern(instrSession, RSSMXV_VALID_ID_RESPONSE_STRING, NULL));
    }

    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    RsCore_AfterErrorInInit(instrSession, sessionProperties, error, newInstrSession);
    return error;
}

/// HIFN  This function reads the indicated directory. According to DOS
/// HIFN  convention, wild card characters can be entered in order to query eg. a
/// HIFN  list of all file of a certain type.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR directory/This control specifies the directory in which the command will be
/// HIPAR directory/performed.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufferSize/Output parameter.
/// HIPAR output/This indicator returns the files in the indicated directory as comma
/// HIPAR output/separated strings, for example: 'SPOOL1.WMF','SPOOL2.WMF','SPOOL3.WMF'
ViStatus _VI_FUNC rssmxv_FileDirectory(ViSession instrSession,
                                       ViString  directory,
                                       ViInt32   bufferSize,
                                       ViChar    output[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidNullPointer(instrSession, directory),
                2, "Directory");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":MMEM:CAT? '%s'", directory);
    checkErr(RsCore_QueryViStringUnknownLengthToUserBuffer(instrSession, cmd, bufferSize, output, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the number of files in the current or in the specified
/// HIFN  directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR directory/This control specifies the directory in which the command will be
/// HIPAR directory/performed.
/// HIPAR numberofFilesAndFolders/Returns the number of files and subdirectories of the current or of a
/// HIPAR numberofFilesAndFolders/specified directory.
ViStatus _VI_FUNC rssmxv_FileCount(ViSession instrSession,
                                   ViString  directory,
                                   ViInt32*  numberofFilesAndFolders)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    if (!isNullOrEmpty(directory))
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:CAT:LENG? '%s'", directory);
    else
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:CAT:LENG?");

    checkErr(RsCore_QueryViInt32(instrSession, cmd, numberofFilesAndFolders));
    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function reads out the subdirectories of the specified directory.
/// HIFN  If no directory is specified, the default directory selected with the
/// HIFN  MMEM:CDIR command is read out. The directories are output in a list
/// HIFN  (the list entries are separated by commas).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR directory/This control specifies the directory in which the command will be
/// HIPAR directory/performed.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufferSize/Output parameter.
/// HIPAR output/This indicator returns names of the subdirectories separated by
/// HIPAR output/colons. The first two strings are related to the parent directory.
ViStatus _VI_FUNC rssmxv_FileSubDirectory(ViSession instrSession,
                                          ViString  directory,
                                          ViInt32   bufferSize,
                                          ViChar    output[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidNullPointer(instrSession, directory),
                2, "Directory");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:DCAT? '%s'", directory);
    checkErr(rssmxv_QueryViString(instrSession, cmd, bufferSize, output));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns out the number of subdirectories in the specified directory.
/// HIFN  If no directory is specified, the directory selected with the MMEM:CDIR
/// HIFN  command is read out.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR directory/This control specifies the directory in which the command will be
/// HIPAR directory/performed.
/// HIPAR numberofFilesAndFolders/Returns the number number of parent and subdirectories.
ViStatus _VI_FUNC rssmxv_FileSubDirectoryCount(ViSession instrSession,
                                               ViString  directory,
                                               ViInt32*  numberofFilesAndFolders)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf = cmd;

    checkErr(RsCore_LockSession(instrSession));

    viCheckAlloc(numberofFilesAndFolders);

    p2buf += sprintf(p2buf, "MMEM:DCAT:LENG?");

    if ((directory != NULL) && (strlen(directory) > 0))
        sprintf(p2buf, " '%s'", directory);

    checkErr(RsCore_QueryViInt32(instrSession, cmd, numberofFilesAndFolders));
    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Renames an existing file ('Source') if no path is specified for
/// HIFN  'Destination'. Otherwise the file is moved to the specified path and
/// HIFN  stored under the original file name or, if specified, a new file name.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR source/Define file source.
/// HIPAR destination/Define file destination.
ViStatus _VI_FUNC rssmxv_MoveFile(ViSession instrSession,
                                  ViString  source,
                                  ViString  destination)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:MOVE '%s','%s'", source, destination);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Copies the first specified file to the second specified file. Instead
/// HIFN  of just a file, this function can also be used to copy a complete
/// HIFN  directory together with all its files.
/// HIFN
/// HIFN     If <destination> is not specified, <source> is copied to the MMEM:MSIS
/// HIFN  drive and the MMEM:CDIR directory. Files which already exist with the
/// HIFN  same name in the destination directory are overwritten without an error
/// HIFN  message.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR source/Define file source.
/// HIPAR destination/Define file destination.
ViStatus _VI_FUNC rssmxv_CopyFile(ViSession instrSession,
                                  ViString  source,
                                  ViString  destination)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:COPY '%s','%s'", source, destination);
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes the specified file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR filename/Deletes the specified file.
ViStatus _VI_FUNC rssmxv_FileDelete(ViSession instrSession,
                                    ViString  filename)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, "", RSSMXV_ATTR_MMEMORY_DELETE, filename),
            2, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Changes the default directory. This directory is used for all
/// HIFN  subsequent MMEM commands if no path is specified with them. It is also
/// HIFN  possible to change to a higher directory using two dots '..'.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR directory/Changes the default directory. This directory is used for all
/// HIPAR directory/subsequent MMEM commands if no path is specified with them. It is also
/// HIPAR directory/possible to change to a higher directory using two dots '..'.
ViStatus _VI_FUNC rssmxv_ChangeDirectory(ViSession instrSession,
                                         ViString  directory)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, "", RSSMXV_ATTR_MMEMORY_CHANGE_DIRECTORY, directory),
            2, "Directory");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Creates a new subdirectory in the specified directory. If no directory
/// HIFN  is specified, a subdirectory is created in the default directory. This
/// HIFN  function can also be used to create a directory tree.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR directory/Creates a new subdirectory in the specified directory. If no directory
/// HIPAR directory/is specified, a subdirectory is created in the default directory. This
/// HIPAR directory/function can also be used to create a directory tree.
ViStatus _VI_FUNC rssmxv_MakeDirectory(ViSession instrSession,
                                       ViString  directory)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, "", RSSMXV_ATTR_MMEMORY_MAKE_DIRECTORY, directory),
            2, "Directory");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes the specified subdirectory in the specified directory. If no
/// HIFN  directory is specified, the subdirectory with the specified name is
/// HIFN  deleted in the default directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR directory/Deletes the specified subdirectory in the specified directory. If no
/// HIPAR directory/directory is specified, the subdirectory with the specified name is
/// HIPAR directory/deleted in the default directory.
ViStatus _VI_FUNC rssmxv_DeleteDirectory(ViSession instrSession,
                                         ViString  directory)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, "", RSSMXV_ATTR_MMEMORY_REMOVE_DIRECTORY, directory),
            2, "Directory");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the user directory, that means the directory the R&S SMCV100B
/// HIFN  stores user files on.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR arraySize/Array size parameter.
/// HIPAR userPath/Queries the user directory, that means the directory the R&S SMCV100B
/// HIPAR userPath/stores user files on.
ViStatus _VI_FUNC rssmxv_GetUserPath(ViSession instrSession,
                                     ViInt32   arraySize,
                                     ViChar    userPath[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_GetAttributeViString(instrSession, "", RSSMXV_ATTR_MMEMORY_USER_PATH,
            arraySize, userPath),
            3, "User Path");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the drive (or network resource in the case of networks) using
/// HIFN  <msus> (MSIS = Mass Storage Identification String). This setting is
/// HIFN  effective for all MMEMory functions where the drive is not explicitly
/// HIFN  specified in the parameter.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR drive/Sets the drive (or network resource in the case of networks) using
/// HIPAR drive/<msus> (MSIS = Mass Storage Identification String). This setting is
/// HIPAR drive/effective for all MMEMory functions where the drive is not explicitly
/// HIPAR drive/specified in the parameter.
ViStatus _VI_FUNC rssmxv_ChangeDrive(ViSession instrSession,
                                     ViString  drive)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, "", RSSMXV_ATTR_MMEMORY_DRIVE, drive),
            2, "Drive");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Loads the specified file stored under the specified name in an
/// HIFN  internal memory. After the file has been loaded, the instrument setting
/// HIFN  must be activated using an *RCL command.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR number/Determines to the specific <number> to be used with the *RCL command,
/// HIPAR number/e.g. *RCL 4.
/// HIPAR filename/File name parameter.
ViStatus _VI_FUNC rssmxv_LoadState(ViSession instrSession,
                                   ViInt32   number,
                                   ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:LOAD:STAT %ld,'%s'\n", number, filename);
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Stores the current instrument setting in the specified file. The
/// HIFN  instrument setting must first be stored in an internal memory with the
/// HIFN  same number using the common command *SAV.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR number/Corresponds to the specific <number> defined with the *SAV command,
/// HIPAR number/e.g. *SAV 4.
/// HIPAR filename/File name parameter.
ViStatus _VI_FUNC rssmxv_StoreState(ViSession instrSession,
                                    ViInt32   number,
                                    ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:STOR:STAT %ld,'%s'\n", number, filename);
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function is used to read data from the instrument and write it to
/// HIFN  a user specified file on the host computer.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR source/This control selects file for the data transfer from instrument to
/// HIPAR source/control computer.
/// HIPAR destination/This control defines destination file to which the data transfer from
/// HIPAR destination/instrument to control computer applies.
ViStatus _VI_FUNC rssmxv_ReadToFileFromInstrument(ViSession instrSession,
                                                  ViString  source,
                                                  ViString  destination)
{
    return rssmxv_readToFile(instrSession, source, destination);
}


/// HIFN  This function is used to read data from the host computer and write it
/// HIFN  to a user specified file in the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR source/This control selects file for the data transfer from control computer
/// HIPAR source/to instrument.
/// HIPAR destination/This control defines destination file to which the data transfer from
/// HIPAR destination/control computer to instrument applies.
ViStatus _VI_FUNC rssmxv_WriteFromFileToInstrument(ViSession instrSession,
                                                   ViString  source,
                                                   ViString  destination)
{
    return rssmxv_writeFromFile(instrSession, source, destination);
}


/// HIFN  Loads a file with previously saved instrument settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR filename/Loads a file with previously saved instrument settings.
ViStatus _VI_FUNC rssmxv_RecallInstrumentSettings(ViSession instrSession,
                                                  ViString  filename)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, "", RSSMXV_ATTR_SYSTEM_LOAD_INSTRUMENT_SETTINGS, filename),
            2, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Saves the current instrument settings to a file with defined filename.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR filename/Saves the current instrument settings to a file with defined filename.
ViStatus _VI_FUNC rssmxv_SaveInstrumentSettings(ViSession instrSession,
                                                ViString  filename)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, "", RSSMXV_ATTR_SYSTEM_SAVE_INSTRUMENT_SETTINGS, filename),
            2, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the ARB generator by specifying the sample
/// HIFN  frequency, selected waveform and state.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR waveform/Selects an existing waveform file, i.e. file with extension *.wv.
/// HIPAR clockFrequency/Sets the clock rate in samples. Loading a waveform sets the clock rate
/// HIPAR clockFrequency/that is defined in the waveform tag 'clock'. This function subsequently
/// HIPAR clockFrequency/changes the clock rate; see data sheet for value range.
/// HIPAR enabled/Enables the ARB generator.
ViStatus _VI_FUNC rssmxv_ConfigureArb(ViSession instrSession,
                                      ViInt32   path,
                                      ViString  waveform,
                                      ViReal64  clockFrequency,
                                      ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_ARB_LOAD_WAVEFORM, waveform),
            3, "Waveform");

    if (clockFrequency != 0.0)
    {
        viCheckParm(rssmxv_SetAttributeViReal64(instrSession, repCap, RSSMXV_ATTR_ARB_CLOCK_FREQUENCY, clockFrequency),
                4, "Clock Frequency");
    }

    viCheckParm(rssmxv_SetAttributeViBoolean(instrSession, repCap, RSSMXV_ATTR_ARB_ENABLED, enabled),
            5, "ARB Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function adds a blank segment to the multi segment file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR sampleCount/Specifies the number of samples.
/// HIPAR frequency/Determines the clock rate.
ViStatus _VI_FUNC rssmxv_ARBMultisegmentAddBlankSegment(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViReal64  sampleCount,
                                                        ViReal64  frequency)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, path, 1, 1),
            2, "Path");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, sampleCount, 512.0, 1.0e+7), 3, "Sample Count");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SOUR%ld:BB:ARB:WSEG:CONF:BLAN:APP %.12lG,%.12lG", path, sampleCount,
             frequency);
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function appends a new segment to the selected sequencing play
/// HIFN  list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR state/Activates/deactivates the appended segment.
/// HIPAR segment/Indicates the number of the segment as in the multi segment waveform
/// HIPAR segment/file.
/// HIPAR repetition/Defines how many times this segment is repeated.
/// HIPAR next/Determines the action after completing the current segment, like for
/// HIPAR next/instance which segment is processed after the processing of the current
/// HIPAR next/one is finished.
ViStatus _VI_FUNC rssmxv_ARBMultisegmentAppendSegmentToPlayList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViBoolean state,
                            ViInt32   segment,
                            ViInt32   repetition,
                            ViInt32   action)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2string;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, path, 1, 1),
            2, "Path");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, repetition, 1, 1048575),
            5, "Sample Count");
    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsSMxV_rngARBMultisegmentAppendAction,
                    action, &p2string), 6, "Action");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SOUR%ld:BB:ARB:WSEG:SEQ:APP %s,%ld,%ld,%s\n", path, state ? "ON" : "OFF",
             segment, repetition, p2string);
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets all ARB generator parameters to their default values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
ViStatus _VI_FUNC rssmxv_ClearAllArbWaveforms(ViSession instrSession,
                                              ViInt32   path)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    checkErr(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_ARB_SET_TO_DEFAULT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects an existing waveform file, i.e. file with extension *.wv.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR fileName/File name parameter is a string. It completes the file path and file
/// HIPAR fileName/name with extention (*.wv).
ViStatus _VI_FUNC rssmxv_LoadARBWaveformFile(ViSession instrSession,
                                             ViInt32   path,
                                             ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_ARB_LOAD_WAVEFORM, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function appends information on the ARB clock rate to specified
/// HIFN  waveform file. The file must contain I/Q and/or marker data and have
/// HIFN  been created with the command: MMEMory:DATA:UNPRotected
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR fileName/File name parameter is a string. It completes the file path and file
/// HIPAR fileName/name with extention (*.wv).
/// HIPAR clock/Sets the Clock parameter.
ViStatus _VI_FUNC rssmxv_WriteARBClockWaveformFile(ViSession instrSession,
                                                   ViInt32   path,
                                                   ViString  fileName,
                                                   ViReal64  clock)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, path, 1, 1),
            2, "Path");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, clock, 400.0, 100.0e+06), 4, "Clock");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SOUR%ld:BB:ARB:WAV:CLOC \"%s\",%.12lG", path, fileName, clock);

    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function writes the block data <binary block data> to the file
/// HIFN  identified by <file_name>.
/// HIFN
/// HIFN     Using this command, waveforms can be sent directly to the instrument.
/// HIFN
/// HIFN     Only the file name has to be entered, the file extension may be
/// HIFN  omitted. Waveform data is stored only in files with the specific file
/// HIFN  extensions *.wv.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path.
/// HIPAR fileName/File name parameter is a string. It completes the file path and file
/// HIPAR fileName/name with extention (*.wv).
/// HIPAR arraySize/Defines the number of elements in the 'Waveform Data' array.
/// HIPAR waveformData/Writes the block data to the file identified by file name.
ViStatus _VI_FUNC rssmxv_ARBWaveformDataWrite(ViSession instrSession,
                                              ViInt32   path,
                                              ViString  fileName,
                                              ViInt32   arraySize,
                                              ViUInt8   waveformData[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, path, 1, 1),
            2, "Path");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FORM PACK;:SOUR%ld:BB:ARB:WAV:DATA '%s',", path, fileName);
    checkErr(RsCore_WriteBinaryDataBlock(instrSession, cmd, waveformData, arraySize));

    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function reads the block data (binary block data) from the file
/// HIFN  identified by <file name> and <waveform tag> parameter.
/// HIFN
/// HIFN     Using this function, waveforms can be sent directly from the
/// HIFN  instrument to the host computer.
/// HIFN
/// HIFN     Only the file name has to be entered, the file extension may be
/// HIFN  omitted.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path.
/// HIPAR fileName/File name parameter is a string. It completes the file path and file
/// HIPAR fileName/name with extention (*.wv).
/// HIPAR waveformTag/Specifies waveform tag parameter.
/// HIPAR bufferSize/Sets the array size.
/// HIPAR readedData/Reads the block data (binary block data) from the file identified by
/// HIPAR readedData/<file name> and <waveform tag> parameter.
ViStatus _VI_FUNC rssmxv_ARBWaveformDataRead(ViSession instrSession,
                                             ViInt32   path,
                                             ViString  fileName,
                                             ViString  waveformTag,
                                             ViInt32   bufferSize,
                                             ViChar    waveformData[],
                                             ViInt32*  returnedValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViByte*  response = NULL;
    ViInt64  responseLen = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, path, 1, 1),
            2, "Path");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SOUR%ld:BB:ARB:WAV:DATA? '%s','%s'", path, fileName, waveformTag);
    checkErr(RsCore_QueryBinaryDataBlock(instrSession, cmd, VI_TRUE, NULL, &response, &responseLen));

    checkErr(rssmxv_CheckStatus(instrSession));

    checkErr(RsCore_CopyToUserBufferBinData((ViBuf)waveformData, bufferSize, response, responseLen));

    if (returnedValues) *returnedValues = (ViInt32)responseLen;

Error:
    if (response)
        free(response);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Loads the settings file in the default directory. A path can also be
/// HIFN  specified, in which case the files in the specified directory are
/// HIFN  selected. If a settings file with the specified name does not yet
/// HIFN  exist, it is created. The file extension may be omitted. Only files
/// HIFN  with the file extension *.arb_multcarr will be loaded or created.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR fileName/File name parameter is a string. It completes the file path and file
/// HIPAR fileName/name with extention (*.wv).
ViStatus _VI_FUNC rssmxv_LoadARBMultiCarrierSettingFile(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_ARB_LOAD_MULTI_CARRIER_SETTING_FILE, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Loads the settings file in the default directory. A path can also be
/// HIFN  specified, in which case the files in the specified directory are
/// HIFN  selected. If a settings file with the specified name does not yet
/// HIFN  exist, it is created. The file extension may be omitted. Only files
/// HIFN  with the file extension *.arb_multcarr will be loaded or created.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR fileName/File name parameter is a string. It completes the file path and file
/// HIPAR fileName/name with extention (*.wv).
ViStatus _VI_FUNC rssmxv_StoreARBMultiCarrierSettingFile(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_ARB_STORE_MULTI_CARRIER_SETTING_FILE, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the file name of the output multi-segment waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR fileName/File name parameter is a string. It completes the file path and file
/// HIPAR fileName/name with extention (*.wv).
ViStatus _VI_FUNC rssmxv_StoreARBMultisegmentFile(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_ARB_MULTISEGMENT_SAVE_FILE, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Appends the specified waveform to the configuration file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR fileName/File name parameter is a string. It completes the file path and file
/// HIPAR fileName/name with extention (*.wv).
ViStatus _VI_FUNC rssmxv_AppendARBMultisegmentFile(ViSession instrSession,
                                                   ViInt32   path,
                                                   ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_ARB_MULTISEGMENT_APPEND_FILE, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Creates a multi segment waveform using the current settings of the
/// HIFN  specified configuration file. The multi segment waveform is saved into
/// HIFN  the file defined in the configuration file. The file extension is *.
/// HIFN  wv.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR fileName/File name parameter is a string. It completes the file path and file
/// HIPAR fileName/name with extention (*.wv).
ViStatus _VI_FUNC rssmxv_ARBMultisegmentCreateFromConfigurationFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_ARB_MULTISEGMENT_CREATE_FROM_CONFIGURATION_FILE, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Creates a multi segment waveform using the current entries of the
/// HIFN  specified configuration file.
/// HIFN     This multi segment waveform is saved with the file name specified in
/// HIFN  the configuration file . The file extension is *. wv. Digital standard
/// HIFN  ARB is activated, the new multi segment waveform is loaded and the
/// HIFN  first segment is output in accordance to the trigger settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR fileName/File name parameter is a string. It completes the file path and file
/// HIPAR fileName/name with extention (*.wv).
ViStatus _VI_FUNC rssmxv_ARBMultisegmentLoadFromConfigurationFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_ARB_MULTISEGMENT_LOAD_FROM_CONFIGURATION_FILE, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes the configuration file. The configuration files are used to
/// HIFN  create multi segment waveform files.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR fileName/File name parameter is a string. It completes the file path and file
/// HIPAR fileName/name with extention (*.wv).
ViStatus _VI_FUNC rssmxv_ARBMultisegmentDeleteFromConfigurationFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_ARB_MULTISEGMENT_DELETE_CONFIGURATION_FILE, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the test signal waveform file name.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR fileName/File name parameter is a string. It completes the file path and file
/// HIPAR fileName/name with extention (*.wv).
ViStatus _VI_FUNC rssmxv_GenerateARBSineTestsignal(ViSession instrSession,
                                                   ViInt32   path,
                                                   ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_ARB_TSIGNAL_GENERATE, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Generates a signal and saves it to a waveform file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR fileName/File name parameter is a string. It completes the file path and file
/// HIPAR fileName/name with extention (*.wv).
ViStatus _VI_FUNC rssmxv_ConfigureARBRectangleTestsignalName(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_ARB_TSIGNAL_RECTANGLE_NAME, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Generates a signal and saves it to a waveform file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR fileName/File name parameter is a string. It completes the file path and file
/// HIPAR fileName/name with extention (*.wv).
ViStatus _VI_FUNC rssmxv_ConfigureARBCIQTestsignalName(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_ARB_TSIGNAL_CIQ_NAME, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates the standard and deactivates all the other digital standards
/// HIFN  and digital modulation modes in the same path.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR enabled/Activates the standard and deactivates all the other digital standards
/// HIPAR enabled/and digital modulation modes in the same path.
ViStatus _VI_FUNC rssmxv_ConfigureDRMEnabled(ViSession instrSession,
                                             ViInt32   path,
                                             ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViBoolean(instrSession, repCap, RSSMXV_ATTR_DRM_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the parameters of the digital standard to their default values
/// HIFN  (*RST values specified for the commands).Not affected is the state set
/// HIFN  with RSSMXV_ATTR_DRM_ENABLED.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
ViStatus _VI_FUNC rssmxv_ConfigureDRMSetToDefault(ViSession instrSession,
                                                  ViInt32   path)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    checkErr(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DRM_SET_TO_DEFAULT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Loads the selected file from the default or the specified directory.
/// HIFN  Loaded are files with extensions *.drm.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Loads the selected file from the default or the specified directory.
/// HIPAR filename/Loaded are files with extensions *.drm.
ViStatus _VI_FUNC rssmxv_RecallDRMSettings(ViSession instrSession,
                                           ViInt32   path,
                                           ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DRM_RECALL_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Saves the current settings into the selected file; the file extension
/// HIFN  (*.drm) is assigned automatically.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Saves the current settings into the selected file; the file extension
/// HIPAR filename/(*.drm) is assigned automatically.
ViStatus _VI_FUNC rssmxv_SaveDRMSettings(ViSession instrSession,
                                         ViInt32   path,
                                         ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DRM_SAVE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Deletes the selected file from the default or the specified directory.
/// HIFN  Deleted are files with extension *.drm.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Deletes the selected file from the default or the specified directory.
/// HIPAR filename/Deleted are files with extension *.drm.
ViStatus _VI_FUNC rssmxv_DeleteDRMSettings(ViSession instrSession,
                                           ViInt32   path,
                                           ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DRM_DELETE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Loads the specified DCP file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Loads the specified DCP file.
ViStatus _VI_FUNC rssmxv_LoadDRMInputFile(ViSession instrSession,
                                          ViInt32   path,
                                          ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DRM_INTPUT_SELECT_FILE, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates the standard and deactivates all the other digital standards
/// HIFN  and digital modulation modes in the same path.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR enabled/Activates the standard and deactivates all the other digital standards
/// HIPAR enabled/and digital modulation modes in the same path.
ViStatus _VI_FUNC rssmxv_ConfigureAMAudioEnabled(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViBoolean(instrSession, repCap, RSSMXV_ATTR_AM_AUDIO_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the parameters of the digital standard to their default values
/// HIFN  (*RST values specified for the commands).Not affected is the state set
/// HIFN  with the command SOURce<hw>:BB:AM|FM|FM:RDS:STATe.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
ViStatus _VI_FUNC rssmxv_ConfigureAMAudioSetToDefault(ViSession instrSession,
                                                      ViInt32   path)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    checkErr(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_AM_AUDIO_SET_TO_DEFAULT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Loads the selected file from the default or the specified directory.
/// HIFN  Loaded are files with extension *.am/fm/rds.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Loads the selected file from the default or the specified directory.
/// HIPAR filename/Loaded are files with extension *.am/fm/rds.
ViStatus _VI_FUNC rssmxv_RecallAMAudioSettings(ViSession instrSession,
                                               ViInt32   path,
                                               ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_AM_AUDIO_RECALL_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Saves the current settings into the selected file; the file extension
/// HIFN  (*.am/fm/rds) is assigned automatically.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Saves the current settings into the selected file; the file extension
/// HIPAR filename/(*.am/fm/rds) is assigned automatically.
ViStatus _VI_FUNC rssmxv_SaveAMAudioSettings(ViSession instrSession,
                                             ViInt32   path,
                                             ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_AM_AUDIO_SAVE_SETTINGS, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Deletes the selected file from the default or the specified directory.
/// HIFN  Deleted are files with extension *.am/fm/rds.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Deletes the selected file from the default or the specified directory.
/// HIPAR filename/Deleted are files with extension *.am/fm/rds.
ViStatus _VI_FUNC rssmxv_DeleteAMAudioSettings(ViSession instrSession,
                                               ViInt32   path,
                                               ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_AM_AUDIO_DELETE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates the standard and deactivates all the other digital standards
/// HIFN  and digital modulation modes in the same path.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR enabled/Activates the standard and deactivates all the other digital standards
/// HIPAR enabled/and digital modulation modes in the same path.
ViStatus _VI_FUNC rssmxv_ConfigureFMAudioEnabled(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViBoolean(instrSession, repCap, RSSMXV_ATTR_FM_AUDIO_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the parameters of the digital standard to their default values
/// HIFN  (*RST values specified for the commands).Not affected is the state set
/// HIFN  with the command SOURce<hw>:BB:AM|FM|FM:RDS:STATe.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
ViStatus _VI_FUNC rssmxv_ConfigureFMAudioSetToDefault(ViSession instrSession,
                                                      ViInt32   path)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    checkErr(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_FM_AUDIO_SET_TO_DEFAULT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Loads the selected file from the default or the specified directory.
/// HIFN  Loaded are files with extension *.am/fm/rds.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Loads the selected file from the default or the specified directory.
/// HIPAR filename/Loaded are files with extension *.am/fm/rds.
ViStatus _VI_FUNC rssmxv_RecallFMAudioSettings(ViSession instrSession,
                                               ViInt32   path,
                                               ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_FM_AUDIO_RECALL_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Saves the current settings into the selected file; the file extension
/// HIFN  (*.am/fm/rds) is assigned automatically.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Saves the current settings into the selected file; the file extension
/// HIPAR filename/(*.am/fm/rds) is assigned automatically.
ViStatus _VI_FUNC rssmxv_SaveFMAudioSettings(ViSession instrSession,
                                             ViInt32   path,
                                             ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_FM_AUDIO_SAVE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Deletes the selected file from the default or the specified directory.
/// HIFN  Deleted are files with extension *.am/fm/rds.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Deletes the selected file from the default or the specified directory.
/// HIPAR filename/Deleted are files with extension *.am/fm/rds.
ViStatus _VI_FUNC rssmxv_DeleteFMAudioSettings(ViSession instrSession,
                                               ViInt32   path,
                                               ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_FM_AUDIO_DELETE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates the standard and deactivates all the other digital standards
/// HIFN  and digital modulation modes in the same path.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR enabled/Activates the standard and deactivates all the other digital standards
/// HIPAR enabled/and digital modulation modes in the same path.
ViStatus _VI_FUNC rssmxv_ConfigureTDMBDABEnabled(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViBoolean(instrSession, repCap, RSSMXV_ATTR_TDMB_DAB_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the parameters of the digital standard to their default values
/// HIFN  (*RST values specified for the commands). Not affected is the state set
/// HIFN  with the command RSSMXV_ATTR_TDMB_DAB_ENABLED.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
ViStatus _VI_FUNC rssmxv_ConfigureTDMBDABSetToDefault(ViSession instrSession,
                                                      ViInt32   path)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    checkErr(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_TDMB_DAB_SET_TO_DEFAULT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Loads the selected file from the default or the specified directory.
/// HIFN  Loaded are files with extension *.tdmb.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Loads the selected file from the default or the specified directory.
/// HIPAR filename/Loaded are files with extension *.tdmb.
ViStatus _VI_FUNC rssmxv_RecallTDMBDABSettings(ViSession instrSession,
                                               ViInt32   path,
                                               ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_TDMB_DAB_RECALL_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Saves the current settings into the selected file; the file extension
/// HIFN  (*.tdmb) is assigned automatically.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Saves the current settings into the selected file; the file extension
/// HIPAR filename/(*.tdmb) is assigned automatically.
ViStatus _VI_FUNC rssmxv_SaveTDMBDABSettings(ViSession instrSession,
                                             ViInt32   path,
                                             ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_TDMB_DAB_SAVE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Deletes the selected file from the default or the specified directory.
/// HIFN  Deleted are files with extension *.tdmb.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Deletes the selected file from the default or the specified directory.
/// HIPAR filename/Deleted are files with extension *.tdmb.
ViStatus _VI_FUNC rssmxv_DeleteTDMBDABSettings(ViSession instrSession,
                                               ViInt32   path,
                                               ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_TDMB_DAB_DELETE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates the standard and deactivates all the other digital standards
/// HIFN  and digital modulation modes in the same path.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR enabled/Activates the standard and deactivates all the other digital standards
/// HIPAR enabled/and digital modulation modes in the same path.
ViStatus _VI_FUNC rssmxv_ConfigureATSCMHEnabled(ViSession instrSession,
                                                ViInt32   path,
                                                ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViBoolean(instrSession, repCap, RSSMXV_ATTR_ATSCMH_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the parameters of the digital standard to their default values
/// HIFN  (*RST values specified for the commands).Not affected is the state set
/// HIFN  with RSSMXV_ATTR_ATSCMH_ENABLED.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
ViStatus _VI_FUNC rssmxv_ConfigureATSCMHSetToDefault(ViSession instrSession,
                                                     ViInt32   path)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    checkErr(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_ATSCMH_SET_TO_DEFAULT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Loads the selected file from the default or the specified directory.
/// HIFN  Loaded are files with extension *.atscmh.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR filename/Loads the selected file from the default or the specified directory.
/// HIPAR filename/Loaded are files with extension *.atscmh.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
ViStatus _VI_FUNC rssmxv_RecallATSCMHSettings(ViSession instrSession,
                                              ViInt32   path,
                                              ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_ATSCMH_RECALL_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Saves the current settings into the selected file; the file extension
/// HIFN  (*.atscmh) is assigned automatically.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Saves the current settings into the selected file; the file extension
/// HIPAR filename/(*.atscmh) is assigned automatically.
ViStatus _VI_FUNC rssmxv_SaveATSCMHSettings(ViSession instrSession,
                                            ViInt32   path,
                                            ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_ATSCMH_SAVE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Deletes the selected file from the default or the specified directory.
/// HIFN  Deleted are files with extension *.atsm.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Deletes the selected file from the default or the specified directory.
/// HIPAR filename/Deleted are files with extension *.atsm.
ViStatus _VI_FUNC rssmxv_DeleteATSCMHSettings(ViSession instrSession,
                                              ViInt32   path,
                                              ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_ATSCMH_DELETE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates the standard and deactivates all the other digital standards
/// HIFN  and digital modulation modes in the same path.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR enabled/Activates the standard and deactivates all the other digital standards
/// HIPAR enabled/and digital modulation modes in the same path.
ViStatus _VI_FUNC rssmxv_ConfigureATSC3Enabled(ViSession instrSession,
                                               ViInt32   path,
                                               ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViBoolean(instrSession, repCap, RSSMXV_ATTR_ATSC3_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the parameters of the digital standard to their default values
/// HIFN  (*RST values specified for the commands).Not affected is the state set
/// HIFN  with the command RSSMXV_ATTR_ATSC3_ENABLED.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
ViStatus _VI_FUNC rssmxv_ConfigureATSC3SetToDefault(ViSession instrSession,
                                                    ViInt32   path)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    checkErr(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_ATSC3_SET_TO_DEFAULT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Loads the selected file from the default or the specified directory.
/// HIFN  Loaded are files with extension *.atsc30.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Loads the selected file from the default or the specified directory.
/// HIPAR filename/Loaded are files with extension *.atsc30.
ViStatus _VI_FUNC rssmxv_RecallATSC3Settings(ViSession instrSession,
                                             ViInt32   path,
                                             ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_ATSC3_RECALL_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Saves the current settings into the selected file; the file extension
/// HIFN  (*.atsc30) is assigned automatically.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Saves the current settings into the selected file; the file extension
/// HIPAR filename/(*.atsc30) is assigned automatically.
ViStatus _VI_FUNC rssmxv_SaveATSC3Settings(ViSession instrSession,
                                           ViInt32   path,
                                           ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_ATSC3_SAVE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Deletes the selected file from the default or the specified directory.
/// HIFN  Deleted are files with extension *.atsc30.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Deletes the selected file from the default or the specified directory.
/// HIPAR filename/Deleted are files with extension *.atsc30.
ViStatus _VI_FUNC rssmxv_DeleteATSC3Settings(ViSession instrSession,
                                             ViInt32   path,
                                             ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_ATSC3_DELETE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Activates the standard and deactivates all the other digital standards
/// HIFN  and digital modulation modes in the same path.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR enabled/Activates the standard and deactivates all the other digital standards
/// HIPAR enabled/and digital modulation modes in the same path.
ViStatus _VI_FUNC rssmxv_ConfigureDVBTEnabled(ViSession instrSession,
                                              ViInt32   path,
                                              ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViBoolean(instrSession, repCap, RSSMXV_ATTR_DVBT_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the parameters of the digital standard to their default values
/// HIFN  (*RST values specified for the commands). Not affected is the state set
/// HIFN  with the attribute RSSMXV_ATTR_DVBT_ENABLED.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
ViStatus _VI_FUNC rssmxv_ConfigureDVBTSetToDefault(ViSession instrSession,
                                                   ViInt32   path)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    checkErr(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DVBT_SET_TO_DEFAULT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Loads the selected file from the default or the specified directory.
/// HIFN  Loaded are files with extension *.dvbt.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Loads the selected file from the default or the specified directory.
/// HIPAR filename/Loaded are files with extension *.dvbt.
ViStatus _VI_FUNC rssmxv_RecallDVBTSettings(ViSession instrSession,
                                            ViInt32   path,
                                            ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DVBT_RECALL_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Saves the current settings into the selected file; the file extension
/// HIFN  (*.dvbt) is assigned automatically.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Saves the current settings into the selected file; the file extension
/// HIPAR filename/(*.dvbt) is assigned automatically.
ViStatus _VI_FUNC rssmxv_SaveDVBTSettings(ViSession instrSession,
                                          ViInt32   path,
                                          ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DVBT_SAVE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes the selected file from the default or the specified directory.
/// HIFN  Deleted are files with extension *.dvbt.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR dvbTDeleteSettings/Deletes the selected file from the default or the specified directory.
/// HIPAR dvbTDeleteSettings/deleted are files with extension *.dvbt.
ViStatus _VI_FUNC rssmxv_DeleteDVBTSettings(ViSession instrSession,
                                            ViInt32   path,
                                            ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DVBT_DELETE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enables/disables the DVB-S standard.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path.
/// HIPAR enabled/Enables/disables the DVB-S standard.
ViStatus _VI_FUNC rssmxv_ConfigureDVBCEnabled(ViSession instrSession,
                                              ViInt32   path,
                                              ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViBoolean(instrSession, repCap, RSSMXV_ATTR_DVB_C_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the parameters of the digital standard to their default values
/// HIFN  (*RST values specified for the commands). Not affected is the state set
/// HIFN  with the command RSSMXV_ATTR_DVB_C_ENABLED.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path.
ViStatus _VI_FUNC rssmxv_ConfigureDVBCSetToDefault(ViSession instrSession,
                                                   ViInt32   path)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    checkErr(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DVB_C_SET_TO_DEFAULT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Loads the selected file from the default or the specified directory.
/// HIFN  Loaded are files with extension *.dvbc.
/// HIFN
/// HIFN     Refer to 'Accessing Files in the Default or Specified Directory' for
/// HIFN  general information on file handling in the default and in a specific
/// HIFN  directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path.
/// HIPAR filename/Loads the selected file from the default or the specified directory.
/// HIPAR filename/Loaded are files with extension *.dvbc.
ViStatus _VI_FUNC rssmxv_RecallDVBCSettings(ViSession instrSession,
                                            ViInt32   path,
                                            ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DVB_C_RECALL_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Saves the current settings into the selected file; the file extension
/// HIFN  (*.dvbc) is assigned automatically.
/// HIFN
/// HIFN     Refer to 'Accessing Files in the Default or Specified Directory' for
/// HIFN  general information on file handling in the default and in a specific
/// HIFN  directory.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path.
/// HIPAR filename/Saves the current settings into the selected file; the file extension
/// HIPAR filename/(*.dvbc) is assigned automatically.
ViStatus _VI_FUNC rssmxv_SaveDVBCSettings(ViSession instrSession,
                                          ViInt32   path,
                                          ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DVB_C_SAVE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes the selected file from the default or the specified directory.
/// HIFN  Deleted are files with extension *.dvbc.
/// HIFN
/// HIFN     Refer to 'Accessing Files in the Default or Specified Directory' for
/// HIFN  general information on file handling in the default and in a specific
/// HIFN  directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path.
/// HIPAR filename/Deletes the selected file from the default or the specified directory.
/// HIPAR filename/Deleted are files with extension *.dvbc.
ViStatus _VI_FUNC rssmxv_DeleteDVBCSettings(ViSession instrSession,
                                            ViInt32   path,
                                            ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DVB_C_DELETE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the files with settings in the default directory. Listed are
/// HIFN  files with the file extension *.dvbc.
/// HIFN
/// HIFN     Refer to 'Accessing Files in the Default or Specified Directory' for
/// HIFN  general information on file handling in the default and in a specific
/// HIFN  directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path.
/// HIPAR bufferSize/Size of output array.
/// HIPAR catalog/Queries the files with settings in the default directory. Listed are
/// HIPAR catalog/files with the file extension *.dvbc.
/// HIPAR bytesRead/
ViStatus _VI_FUNC rssmxv_QueryDVBCSettingsCatalog(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViInt32   bufferSize,
                                                  ViChar    catalog[],
                                                  ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    checkErr(RsCore_GetAttributeViStringWithRealLen(instrSession, repCap, RSSMXV_ATTR_DVB_C_SETTINGS_CATALOG, RS_VAL_DIRECT_USER_CALL, bufferSize, catalog, bytesRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates the standard and deactivates all the other digital standards
/// HIFN  and digital modulation modes in the same path.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR enabled/Activates the standard and deactivates all the other digital standards
/// HIPAR enabled/and digital modulation modes in the same path.
ViStatus _VI_FUNC rssmxv_ConfigureDVBT2Enabled(ViSession instrSession,
                                               ViInt32   path,
                                               ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViBoolean(instrSession, repCap, RSSMXV_ATTR_DVBT2_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the parameters of the digital standard to their default values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
ViStatus _VI_FUNC rssmxv_ConfigureDVBT2SetToDefault(ViSession instrSession,
                                                    ViInt32   path)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    checkErr(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DVBT2_SET_TO_DEFAULT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Loads the selected file from the default or the specified directory.
/// HIFN  Loaded are files with extension *.t2dvb.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Loads the selected file from the default or the specified directory.
/// HIPAR filename/Loaded are files with extension *.t2dvb.
ViStatus _VI_FUNC rssmxv_RecallDVBT2Settings(ViSession instrSession,
                                             ViInt32   path,
                                             ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DVBT2_RECALL_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Saves the current settings into the selected file; the file extension
/// HIFN  (*.t2dvb) is assigned automatically.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Saves the current settings into the selected file; the file extension
/// HIPAR filename/(*.t2dvb) is assigned automatically.
ViStatus _VI_FUNC rssmxv_SaveDVBT2Settings(ViSession instrSession,
                                           ViInt32   path,
                                           ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DVBT2_SAVE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes the selected file from the default or the specified directory.
/// HIFN  deleted are files with extension *.t2dvb.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Deletes the selected file from the default or the specified directory.
/// HIPAR filename/deleted are files with extension *.t2dvb.
ViStatus _VI_FUNC rssmxv_DeleteDVBT2Settings(ViSession instrSession,
                                             ViInt32   path,
                                             ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DVBT2_DELETE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Activates the standard and deactivates all the other digital standards
/// HIFN  and digital modulation modes in the same path.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR enabled/Activates the standard and deactivates all the other digital standards
/// HIPAR enabled/and digital modulation modes in the same path.
ViStatus _VI_FUNC rssmxv_ConfigureISDBTEnabled(ViSession instrSession,
                                               ViInt32   path,
                                               ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViBoolean(instrSession, repCap, RSSMXV_ATTR_ISDBT_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the parameters of the digital standard to their default values
/// HIFN  (*RST values specified for the commands).Not affected is the state set
/// HIFN  with the command RSSMXV_ATTR_ISDBT_ENABLED.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
ViStatus _VI_FUNC rssmxv_ConfigureISDBTSetToDefault(ViSession instrSession,
                                                    ViInt32   path)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    checkErr(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_ISDBT_SET_TO_DEFAULT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Accesses the 'Save/Recall' dialog, that is the standard instrument
/// HIFN  function for saving and recalling the complete dialog-related settings
/// HIFN  in a file. The provided navigation possibilities in the dialog are
/// HIFN  self-explanatory.The filename and the directory, in that the settings
/// HIFN  are stored, are user-definable; the file extension is however
/// HIFN  predefined.See also 'File and Data Management'.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Accesses the 'Save/Recall' dialog, that is the standard instrument
/// HIPAR filename/function for saving and recalling the complete dialog-related settings
/// HIPAR filename/in a file. The provided navigation possibilities in the dialog are
/// HIPAR filename/self-explanatory.The filename and the directory, in that the settings
/// HIPAR filename/are stored, are user-definable; the file extension is however
/// HIPAR filename/predefined.See also 'File and Data Management'.
ViStatus _VI_FUNC rssmxv_RecallISDBTSettings(ViSession instrSession,
                                             ViInt32   path,
                                             ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_ISDBT_RECALL_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Accesses the 'Save/Recall' dialog, that is the standard instrument
/// HIFN  function for saving and recalling the complete dialog-related settings
/// HIFN  in a file. The provided navigation possibilities in the dialog are
/// HIFN  self-explanatory.The filename and the directory, in that the settings
/// HIFN  are stored, are user-definable; the file extension is however
/// HIFN  predefined.See also 'File and Data Management'.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Accesses the 'Save/Recall' dialog, that is the standard instrument
/// HIPAR filename/function for saving and recalling the complete dialog-related settings
/// HIPAR filename/in a file. The provided navigation possibilities in the dialog are
/// HIPAR filename/self-explanatory.The filename and the directory, in that the settings
/// HIPAR filename/are stored, are user-definable; the file extension is however
/// HIPAR filename/predefined.See also 'File and Data Management'.
ViStatus _VI_FUNC rssmxv_SaveISDBTSettings(ViSession instrSession,
                                           ViInt32   path,
                                           ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_ISDBT_SAVE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes the selected file from the default or the specified directory.
/// HIFN  deleted are files with extension *.isdbt.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Deletes the selected file from the default or the specified directory.
/// HIPAR filename/deleted are files with extension *.isdbt.
ViStatus _VI_FUNC rssmxv_DeleteISDBTSettings(ViSession instrSession,
                                             ViInt32   path,
                                             ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_ISDBT_DELETE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Activates the standard and deactivates all the other digital standards
/// HIFN  and digital modulation modes in the same path.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR enabled/Activates the standard and deactivates all the other digital standards
/// HIPAR enabled/and digital modulation modes in the same path.
ViStatus _VI_FUNC rssmxv_ConfigureDTMBEnabled(ViSession instrSession,
                                              ViInt32   path,
                                              ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViBoolean(instrSession, repCap, RSSMXV_ATTR_DTMB_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the parameters of the digital standard to their default values
/// HIFN  (*RST values specified for the commands).Not affected is the state set
/// HIFN  with the command RSSMXV_ATTR_DTMB_ENABLED.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
ViStatus _VI_FUNC rssmxv_ConfigureDTMBSetToDefault(ViSession instrSession,
                                                   ViInt32   path)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    checkErr(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DTMB_SET_TO_DEFAULT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Accesses the 'Save/Recall' dialog, that is the standard instrument
/// HIFN  function for saving and recalling the complete dialog-related settings
/// HIFN  in a file. The provided navigation possibilities in the dialog are
/// HIFN  self-explanatory.The filename and the directory, in that the settings
/// HIFN  are stored, are user-definable; the file extension is however
/// HIFN  predefined.See also 'File and Data Management'.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Accesses the 'Save/Recall' dialog, that is the standard instrument
/// HIPAR filename/function for saving and recalling the complete dialog-related settings
/// HIPAR filename/in a file. The provided navigation possibilities in the dialog are
/// HIPAR filename/self-explanatory.The filename and the directory, in that the settings
/// HIPAR filename/are stored, are user-definable; the file extension is however
/// HIPAR filename/predefined.See also 'File and Data Management'.
ViStatus _VI_FUNC rssmxv_RecallDTMBSettings(ViSession instrSession,
                                            ViInt32   path,
                                            ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DTMB_RECALL_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Accesses the 'Save/Recall' dialog, that is the standard instrument
/// HIFN  function for saving and recalling the complete dialog-related settings
/// HIFN  in a file. The provided navigation possibilities in the dialog are
/// HIFN  self-explanatory.The filename and the directory, in that the settings
/// HIFN  are stored, are user-definable; the file extension is however
/// HIFN  predefined.See also 'File and Data Management'.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Accesses the 'Save/Recall' dialog, that is the standard instrument
/// HIPAR filename/function for saving and recalling the complete dialog-related settings
/// HIPAR filename/in a file. The provided navigation possibilities in the dialog are
/// HIPAR filename/self-explanatory.The filename and the directory, in that the settings
/// HIPAR filename/are stored, are user-definable; the file extension is however
/// HIPAR filename/predefined.See also 'File and Data Management'.
ViStatus _VI_FUNC rssmxv_SaveDTMBSettings(ViSession instrSession,
                                          ViInt32   path,
                                          ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DTMB_SAVE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Deletes the selected file from the default or the specified directory.
/// HIFN  Deleted are files with extension *.dtmb.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Deletes the selected file from the default or the specified directory.
/// HIPAR filename/Deleted are files with extension *.dtmb.
ViStatus _VI_FUNC rssmxv_DeleteDTMBSettings(ViSession instrSession,
                                            ViInt32   path,
                                            ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DTMB_DELETE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enables/disables the DVB-S standard.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR enabled/Enables/disables the DVB-S standard.
ViStatus _VI_FUNC rssmxv_ConfigureDVBSEnabled(ViSession instrSession,
                                              ViInt32   path,
                                              ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViBoolean(instrSession, repCap, RSSMXV_ATTR_DVBS_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the parameters of the digital standard to their default values
/// HIFN  (*RST values specified for the commands).Not affected is the state set
/// HIFN  with the attribute RSSMXV_ATTR_DVBS_ENABLED.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
ViStatus _VI_FUNC rssmxv_ConfigureDVBSSetToDefault(ViSession instrSession,
                                                   ViInt32   path)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    checkErr(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DVBS_SET_TO_DEFAULT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Loads the selected file from the default or the specified directory.
/// HIFN  Loaded are files with extension *.dvbs.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Loads the selected file from the default or the specified directory.
/// HIPAR filename/Loaded are files with extension *.dvbs.
ViStatus _VI_FUNC rssmxv_RecallDVBSSettings(ViSession instrSession,
                                            ViInt32   path,
                                            ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DVBS_RECALL_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Saves the current settings into the selected file; the file extension
/// HIFN  (*.dvbs) is assigned automatically.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Saves the current settings into the selected file; the file extension
/// HIPAR filename/(*.dvbs) is assigned automatically.
ViStatus _VI_FUNC rssmxv_SaveDVBSSettings(ViSession instrSession,
                                          ViInt32   path,
                                          ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DVBS_SAVE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Deletes the selected file from the default or the specified directory.
/// HIFN  Deleted are files with extension *.dvbs.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Deletes the selected file from the default or the specified directory.
/// HIPAR filename/Deleted are files with extension *.dvbs.
ViStatus _VI_FUNC rssmxv_DeleteDVBSSettings(ViSession instrSession,
                                            ViInt32   path,
                                            ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DVBS_DELETE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enables/disables the J83B standard.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path.
/// HIPAR enabled/Enables/disables the J83B standard.
ViStatus _VI_FUNC rssmxv_ConfigureJ83BEnabled(ViSession instrSession,
                                              ViInt32   path,
                                              ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViBoolean(instrSession, repCap, RSSMXV_ATTR_J83B_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the parameters of the digital standard to their default values
/// HIFN  (*RST values specified for the commands).Not affected is the state set
/// HIFN  with RSSMXV_ATTR_J83B_ENABLED.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path.
ViStatus _VI_FUNC rssmxv_ConfigureJ83BSetToDefault(ViSession instrSession,
                                                   ViInt32   path)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    checkErr(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_J83B_SET_TO_DEFAULT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Loads the selected file from the default or the specified directory.
/// HIFN  Loaded are files with extension *.J83B.
/// HIFN
/// HIFN     Refer to 'Accessing Files in the Default or Specified Directory' for
/// HIFN  general information on file handling in the default and in a specific
/// HIFN  directory.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path.
/// HIPAR filename/Loads the selected file from the default or the specified directory.
/// HIPAR filename/Loaded are files with extension *.J83B.
ViStatus _VI_FUNC rssmxv_RecallJ83BSettings(ViSession instrSession,
                                            ViInt32   path,
                                            ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_J83B_RECALL_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Saves the current settings into the selected file; the file extension
/// HIFN  (*.J83B) is assigned automatically.
/// HIFN
/// HIFN     Refer to 'Accessing Files in the Default or Specified Directory' for
/// HIFN  general information on file handling in the default and in a specific
/// HIFN  directory.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path.
/// HIPAR filename/Saves the current settings into the selected file; the file extension
/// HIPAR filename/(*.J83B) is assigned automatically.
ViStatus _VI_FUNC rssmxv_SaveJ83BSettings(ViSession instrSession,
                                          ViInt32   path,
                                          ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_J83B_SAVE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the files with settings in the default directory. Listed are
/// HIFN  files with the file extension *.J83B.
/// HIFN
/// HIFN     Refer to 'Accessing Files in the Default or Specified Directory' for
/// HIFN  general information on file handling in the default and in a specific
/// HIFN  directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path.
/// HIPAR bufferSize/Size of output array.
/// HIPAR settingsCatalog/Queries the files with settings in the default directory. Listed are
/// HIPAR settingsCatalog/files with the file extension *.J83B.
/// HIPAR bytesRead/
ViStatus _VI_FUNC rssmxv_QueryJ83BSettingsCatalog(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViInt32   bufferSize,
                                                  ViChar    settingsCatalog[],
                                                  ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    checkErr(RsCore_GetAttributeViStringWithRealLen(instrSession, repCap, RSSMXV_ATTR_J83B_SETTINGS_CATALOG, RS_VAL_DIRECT_USER_CALL, bufferSize, settingsCatalog, bytesRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes the selected file from the default or the specified directory.
/// HIFN  Deleted are files with extension *.J83B.
/// HIFN
/// HIFN     Refer to 'Accessing Files in the Default or Specified Directory' for
/// HIFN  general information on file handling in the default and in a specific
/// HIFN  directory.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path.
/// HIPAR filename/Deletes the selected file from the default or the specified directory.
/// HIPAR filename/Deleted are files with extension *.J83B.
ViStatus _VI_FUNC rssmxv_DeleteJ83BSettings(ViSession instrSession,
                                            ViInt32   path,
                                            ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_J83B_DELETE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates the standard and deactivates all the other digital standards
/// HIFN  and digital modulation modes in the same path.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR enabled/Activates the standard and deactivates all the other digital standards
/// HIPAR enabled/and digital modulation modes in the same path.
ViStatus _VI_FUNC rssmxv_ConfigureDVBS2Enabled(ViSession instrSession,
                                               ViInt32   path,
                                               ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViBoolean(instrSession, repCap, RSSMXV_ATTR_DVBS2_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the parameters of the digital standard to their default values
/// HIFN  (*RST values specified for the commands). Not affected is the state set
/// HIFN  with the attribute RSSMXV_ATTR_DVBS2_ENABLED.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
ViStatus _VI_FUNC rssmxv_ConfigureDVBS2SetToDefault(ViSession instrSession,
                                                    ViInt32   path)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    checkErr(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DVBS2_SET_TO_DEFAULT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Loads the selected file from the default or the specified directory.
/// HIFN  Loaded are files with extension *.d2vbs.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Loads the selected file from the default or the specified directory.
/// HIPAR filename/Loaded are files with extension *.d2vbs.
ViStatus _VI_FUNC rssmxv_RecallDVBS2Settings(ViSession instrSession,
                                             ViInt32   path,
                                             ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DVBS2_RECALL_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Saves the current settings into the selected file; the file extension
/// HIFN  (*.d2vbs) is assigned automatically.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Saves the current settings into the selected file; the file extension
/// HIPAR filename/(*.d2vbs) is assigned automatically.
ViStatus _VI_FUNC rssmxv_SaveDVBS2Settings(ViSession instrSession,
                                           ViInt32   path,
                                           ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DVBS2_SAVE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes the selected file from the default or the specified directory.
/// HIFN  deleted are files with extension *.d2vbs.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path. This parameter is ignored and can be null.
/// HIPAR filename/Deletes the selected file from the default or the specified directory.
/// HIPAR filename/deleted are files with extension *.d2vbs.
ViStatus _VI_FUNC rssmxv_DeleteDVBS2Settings(ViSession instrSession,
                                             ViInt32   path,
                                             ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DVBS2_DELETE_SETTINGS, filename),
            3, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the signal generator to apply IQ (vector)
/// HIFN  modulation to the RF output signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR iqEnabled/Activates and deactivates IQ modulation.
ViStatus _VI_FUNC rssmxv_ConfigureIQEnabled(ViSession instrSession,
                                            ViInt32   path,
                                            ViBoolean iqEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViBoolean(instrSession, repCap, RSSMXV_ATTR_IQ_ENABLED, iqEnabled),
            3, "IQ Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function configures the signal generator to apply IQ (vector)
/// HIFN  modulation to the RF output signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR swapEnabled/When set to ON, this command swaps the I and Q channel.
ViStatus _VI_FUNC rssmxv_ConfigureIQ(ViSession instrSession,
                                     ViInt32   path,
                                     ViBoolean swapEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViBoolean(instrSession, repCap, RSSMXV_ATTR_IQ_SWAP_ENABLED, swapEnabled),
            3, "Swap Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function configures the IQ Digital Output state.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR iqDigitalEnabled/Switches on and off the digital I/Q output signals.
ViStatus _VI_FUNC rssmxv_ConfigureIQOutputDigitalEnabled(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViBoolean iqDigitalEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViBoolean(instrSession, repCap, RSSMXV_ATTR_IQ_OUTPUT_DIGITAL_ENABLED, iqDigitalEnabled),
            3, "IQ Digital Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function switches on digital modulation. Switching on digital
/// HIFN  modulation turns off all the other digital standards on the same path
/// HIFN  (SOURce1 or SOURce2).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR dmEnabled/Switches on digital modulation. Switching on digital modulation turns
/// HIPAR dmEnabled/off all the other digital standards on the same path (SOURce1 or
/// HIPAR dmEnabled/SOURce2).
ViStatus _VI_FUNC rssmxv_ConfigureDMEnabled(ViSession instrSession,
                                            ViInt32   path,
                                            ViBoolean dmEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViBoolean(instrSession, repCap, RSSMXV_ATTR_DM_ENABLED, dmEnabled),
            3, "DM Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function specifies the actual standard used by the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR standard/Selects the standard. After selection, modulation parameters
/// HIPAR standard/Modulation Type, Symbol Rate, Filter and Coding are automatically set
/// HIPAR standard/in accordance with the standard. The standard values are listed in
/// HIPAR standard/section  Set acc. to Standard - Digital Modulation.
ViStatus _VI_FUNC rssmxv_SelectDMStandard(ViSession instrSession,
                                          ViInt32   path,
                                          ViInt32   standard)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViInt32(instrSession, repCap, RSSMXV_ATTR_DM_ACC_TO_STANDARD, standard),
            3, "Standard");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function configures the source of the data for the digital
/// HIFN  modulation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR source/Selects the data source.
ViStatus _VI_FUNC rssmxv_ConfigureDMDataSource(ViSession instrSession,
                                               ViInt32   path,
                                               ViInt32   source)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViInt32(instrSession, repCap, RSSMXV_ATTR_DM_DATA_SOURCE, source),
            3, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function configures the type of the PRBS used as data for the
/// HIFN  digital modulation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR type/Defines the length of the pseudo-random sequence in accordance with
/// HIPAR type/the following equation:
ViStatus _VI_FUNC rssmxv_ConfigureDMPRBSType(ViSession instrSession,
                                             ViInt32   path,
                                             ViInt32   type)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViInt32(instrSession, repCap, RSSMXV_ATTR_DM_PRBS_TYPE, type),
            3, "Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes the selected file with Digital Modulation settings.
/// HIFN
/// HIFN     The folder is set using command MMEM:CDIRectory. A path can also be
/// HIFN  specified, in which case the files in the specified folder are read.
/// HIFN  The file extension may be omitted. Only files with the file extension
/// HIFN  *.dm will be deleted.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR fileName/File name parameter is a string. It completes the file path and file
/// HIPAR fileName/name with extention (*.wv).
ViStatus _VI_FUNC rssmxv_DeleteDMSettings(ViSession instrSession,
                                          ViInt32   path,
                                          ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DM_DELETE_SETTINGS, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Loads the selected file with Digital Modulation settings.
/// HIFN
/// HIFN     The folder is set using command MMEM:CDIRectory. A path can also be
/// HIFN  specified, in which case the files in the specified folder are read.
/// HIFN  The file extension may be omitted. Only files with the file extension
/// HIFN  *.dm will be loaded.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR fileName/File name parameter is a string. It completes the file path and file
/// HIPAR fileName/name with extention (*.wv).
ViStatus _VI_FUNC rssmxv_RecallDMSettings(ViSession instrSession,
                                          ViInt32   path,
                                          ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DM_RECALL_SETTINGS, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Stores the current Digital Modulation settings into the selected file.
/// HIFN
/// HIFN     The folder is set using command MMEM:CDIRectory. A path can also be
/// HIFN  specified, in which case the files in the specified folder are read.
/// HIFN  Only the file name has to be entered. Digital Modulation settings are
/// HIFN  stored as files with the specific file extensions *.dm.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR fileName/File name parameter is a string. It completes the file path and file
/// HIPAR fileName/name with extention (*.wv).
ViStatus _VI_FUNC rssmxv_SaveDMSettings(ViSession instrSession,
                                        ViInt32   path,
                                        ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DM_SAVE_SETTINGS, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes the selected file with Digital Modulation filter settings.
/// HIFN
/// HIFN     The folder is set using command MMEM:CDIRectory. A path can also be
/// HIFN  specified, in which case the files in the specified folder are read.
/// HIFN  The file extension may be omitted. Only files with the file extension
/// HIFN  *.vaf will be deleted.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR fileName/File name parameter is a string. It completes the file path and file
/// HIPAR fileName/name with extention (*.wv).
ViStatus _VI_FUNC rssmxv_DeleteDMFilterList(ViSession instrSession,
                                            ViInt32   path,
                                            ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DM_FILTER_LIST_DELETE, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function enables or disables power ramping.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR enabled/Enables or disables power ramping.
ViStatus _VI_FUNC rssmxv_ConfigureDMPowerRampEnabled(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViBoolean(instrSession, repCap, RSSMXV_ATTR_DM_POWER_RAMPING_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the level attenuation for signal ranges that are flagged with
/// HIFN  level attribute attenuated by the LEV_ATT control signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR attenuation/Sets the level attenuation for signal ranges that are flagged with
/// HIPAR attenuation/level attribute attenuated by the LEV_ATT control signal.
ViStatus _VI_FUNC rssmxv_ConfigureDMPowerRampAttenuation(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViReal64  attenuation)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViReal64(instrSession, repCap, RSSMXV_ATTR_DM_POWER_RAMP_ATTENUATION, attenuation),
            3, "Attenuation");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function configures digital modulation power ramping.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR source/Sets the source for the power ramp control signals.
/// HIPAR function/Sets the edge shape of the ramp envelope.
/// HIPAR time/Sets the power ramping rise time and fall time for a burst.
/// HIPAR riseDelay/Sets the delay in the rising edge. A positive value gives rise to a
/// HIPAR riseDelay/delay and a negative value causes an advance. The setting is expressed
/// HIPAR riseDelay/in symbols.
/// HIPAR fallDelay/Sets the delay in the falling edge. A positive value gives rise to a
/// HIPAR fallDelay/delay and a negative value causes an advance. The setting is expressed
/// HIPAR fallDelay/in symbols.
/// HIPAR attenuation/Sets the level attenuation for signal ranges that are flagged with
/// HIPAR attenuation/level attribute attenuated by the LEV_ATT control signal.
ViStatus _VI_FUNC rssmxv_ConfigureDMPowerRamp(ViSession instrSession,
                                              ViInt32   path,
                                              ViInt32   source,
                                              ViInt32   function,
                                              ViReal64  time,
                                              ViReal64  riseDelay,
                                              ViReal64  fallDelay,
                                              ViReal64  attenuation)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViInt32(instrSession, repCap, RSSMXV_ATTR_DM_POWER_RAMP_SOURCE, source),
            3, "Source");

    viCheckParm(rssmxv_SetAttributeViInt32(instrSession, repCap, RSSMXV_ATTR_DM_POWER_RAMP_FUNCTION, function),
            4, "Function");

    viCheckParm(rssmxv_SetAttributeViReal64(instrSession, repCap, RSSMXV_ATTR_DM_POWER_RAMP_TIME, time),
            5, "Time");

    viCheckParm(rssmxv_SetAttributeViReal64(instrSession, repCap, RSSMXV_ATTR_DM_POWER_RAMP_RISE_DELAY, riseDelay),
            6, "Rise Delay");

    viCheckParm(rssmxv_SetAttributeViReal64(instrSession, repCap, RSSMXV_ATTR_DM_POWER_RAMP_FALL_DELAY, fallDelay),
            7, "Fall Delay");

    viCheckParm(rssmxv_SetAttributeViReal64(instrSession, repCap, RSSMXV_ATTR_DM_POWER_RAMP_ATTENUATION, attenuation),
            8, "Attenuation");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function sets the clock source.
/// HIFN
/// HIFN     Selecting EXTernal is only possible for path A, since the external
/// HIFN  clock source is permanently allocated to path A.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR source/Sets the clock source.
ViStatus _VI_FUNC rssmxv_ConfigureDMClockSource(ViSession instrSession,
                                                ViInt32   path,
                                                ViInt32   source)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViInt32(instrSession, repCap, RSSMXV_ATTR_DM_CLOCK_SOURCE, source),
            3, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Copies the selected control list into the control list specified by
/// HIFN  <list_name>. If a control list with the specified name does not yet
/// HIFN  exist, it is created.
/// HIFN
/// HIFN     The source file has to be available in the default folder. The default
/// HIFN  folder is set using command MMEM:CDIRectory. A path can be specified,
/// HIFN  in which case the source file is copied into the file <list_name> in
/// HIFN  the specified folder. The file extension may be omitted. Only files
/// HIFN  with the file extension *.dm_iqc will be copied.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR fileName/File name parameter is a string. It completes the file path and file
/// HIPAR fileName/name with extention (*.wv).
ViStatus _VI_FUNC rssmxv_CopyDMControlList(ViSession instrSession,
                                           ViInt32   path,
                                           ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DM_CONTROL_LIST_COPY, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Copies the selected control list into the control list specified by
/// HIFN  <list_name>. If a control list with the specified name does not yet
/// HIFN  exist, it is created.
/// HIFN
/// HIFN     The source file has to be available in the default folder. The default
/// HIFN  folder is set using command MMEM:CDIRectory. A path can be specified,
/// HIFN  in which case the source file is copied into the file <list_name> in
/// HIFN  the specified folder. The file extension may be omitted. Only files
/// HIFN  with the file extension *.dm_iqc will be copied.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR fileName/File name parameter is a string. It completes the file path and file
/// HIPAR fileName/name with extention (*.wv).
ViStatus _VI_FUNC rssmxv_DeleteDMControlList(ViSession instrSession,
                                             ViInt32   path,
                                             ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DM_CONTROL_LIST_DELETE, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sends the data to the currently selected control list. If the list
/// HIFN  already contains data, it is overwritten. This function only writes
/// HIFN  data into the data section of the file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR data/Sends the data to the currently selected control list. If the list
/// HIPAR data/already contains data, it is overwritten. This function only writes
/// HIPAR data/data into the data section of the file.
ViStatus _VI_FUNC rssmxv_ConfigureDMControlListDataWrite(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViInt32   numberofValues,
                                                         ViInt16   data[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   parameter[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf = parameter;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_InvalidViInt32RangeMin(instrSession, numberofValues, 0));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    if (numberofValues > 0)
    {
        for (int i = 0; i < numberofValues; i++)
        {
            p2buf += sprintf(p2buf, "%d", data[i]);

            if (i < numberofValues - 1)
                *(p2buf++) = ',';
        }

        *p2buf = '\0';

        viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DM_CONTROL_LIST_DATA_WRITE, parameter),
                3, "Data");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the content of the specified tag in the selected file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR fileName/Sets the name of list from which the tag value should be retrieved.
/// HIPAR tag/Sets the name of tag from which the value should be retrieved.
/// HIPAR arraySize/Sets the array size parameter.
/// HIPAR tagData/Queries the content of the specified tag in the selected file.
ViStatus _VI_FUNC rssmxv_ConfigureDMControlListTags(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViString  fileName,
                                                    ViString  tag,
                                                    ViInt32   arraySize,
                                                    ViChar    tagData[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, path, 1, 1),
            2, "Path");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":SOUR%ld:BB:DM:CLIS:TAG? '%s','%s'", path, fileName, tag);
    checkErr(rssmxv_QueryViString(instrSession, cmd, arraySize, tagData));

    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Copies the selected control list into the control list specified by
/// HIFN  <list_name>. If a control list with the specified name does not yet
/// HIFN  exist, it is created.
/// HIFN
/// HIFN     The source file has to be available in the default folder. The default
/// HIFN  folder is set using command MMEM:CDIRectory. A path can be specified,
/// HIFN  in which case the source file is copied into the file <list_name> in
/// HIFN  the specified folder. The file extension may be omitted. Only files
/// HIFN  with the file extension *.dm_iqc will be copied.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR fileName/File name parameter is a string. It completes the file path and file
/// HIPAR fileName/name with extention (*.wv).
ViStatus _VI_FUNC rssmxv_CopyDMDataList(ViSession instrSession,
                                        ViInt32   path,
                                        ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DM_DATA_LIST_COPY, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes the specified data list from the default folder. The default
/// HIFN  folder is set using command MMEM:CDIRectory. A path can also be
/// HIFN  specified, in which case the files in the specified folder are deleted.
/// HIFN  The file extension may be omitted. Only files with the file extension
/// HIFN  *.dm_iqd will be deleted.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR fileName/File name parameter is a string. It completes the file path and file
/// HIPAR fileName/name with extention (*.wv).
ViStatus _VI_FUNC rssmxv_DeleteDMDataList(ViSession instrSession,
                                          ViInt32   path,
                                          ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DM_DATA_LIST_DELETE, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Reads out the data part of the data list. If the query is expanded by
/// HIFN  using the two parameters <start> and <length>, the list is read out in
/// HIFN  smaller sections. Start and Length are expressed in bits. Without the
/// HIFN  parameters the total length is always read out starting from address 1.
/// HIFN  The byte sequence is defined in the IEC bus standard (read/write most
/// HIFN  significant byte first).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR start/Defines start addres (expressed in bits).
/// HIPAR length/Defines data length (expressed in bits).
/// HIPAR arraySize/Sets the array size parameter.
/// HIPAR readData/Reads out the data part of the data list. If the query is expanded by
/// HIPAR readData/using the two parameters <start> and <length>, the list is read out in
/// HIPAR readData/smaller sections. Start and Length are expressed in bits. Without the
/// HIPAR readData/parameters the total length is always read out starting from address 1.
/// HIPAR readData/The byte sequence is defined in the IEC bus standard (read/write most
/// HIPAR readData/significant byte first).
ViStatus _VI_FUNC rssmxv_ReadDMDataListData(ViSession instrSession,
                                            ViInt32   path,
                                            ViInt32   start,
                                            ViInt32   length,
                                            ViInt32   arraySize,
                                            ViChar    readData[])
{
    ViStatus error = VI_SUCCESS;
    ViChar*  cmd = NULL;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    checkErr(RsCore_BuildAttrCommandString(instrSession, &g_RSSMXV_ATTR_DM_DATA_LIST_DATA_READ_ALL, repCap, &cmd));

    if (length == 0)
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "%s %ld", cmd, start);

    else
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "%s %ld,%ld", cmd, start, length);
    checkErr(rssmxv_QueryViString(instrSession, cmd, arraySize, readData));

    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    if (cmd) free(cmd);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Reads out the entire data list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR arraySize/Sets the array size parameter.
/// HIPAR readData/Reads out the data part of the data list. If the query is expanded by
/// HIPAR readData/using the two parameters <start> and <length>, the list is read out in
/// HIPAR readData/smaller sections. Start and Length are expressed in bits. Without the
/// HIPAR readData/parameters the total length is always read out starting from address 1.
/// HIPAR readData/The byte sequence is defined in the IEC bus standard (read/write most
/// HIPAR readData/significant byte first).
ViStatus _VI_FUNC rssmxv_ReadDMDataListDataAll(ViSession instrSession,
                                               ViInt32   path,
                                               ViInt32   arraySize,
                                               ViChar    readData[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSSMXV_ATTR_DM_DATA_LIST_DATA_READ_ALL,
            "Path", path - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Path");

    viCheckParm(rssmxv_GetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DM_DATA_LIST_DATA_READ_ALL,
            arraySize, readData),
            3, "Read Data");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Appends the bit data onto the end of the existing data in the selected
/// HIFN  data list. This means that existing content in the data list is not
/// HIFN  overwritten. By this means very long data lists can be built up
/// HIFN  piecemeal. The data format is as specified in command
/// HIFN  SOURce:BB:DM:DLISt:DATA.
/// HIFN
/// HIFN     Notes:
/// HIFN
/// HIFN     (1) This function cannot be used with an empty data list, such as one
/// HIFN  that has just been created, for example. In this case the command
/// HIFN  SOURce:BB:DM:DLISt:DATA must first be used to enter modulation data in
/// HIFN  the list.
/// HIFN
/// HIFN     (2) *RST has no effect on data lists.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR dataAppend/Appends the bit data onto the end of the existing data in the selected
/// HIPAR dataAppend/data list.
ViStatus _VI_FUNC rssmxv_AppendDMDataListData(ViSession instrSession,
                                              ViInt32   path,
                                              ViString  dataAppend)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DM_DATA_LIST_DATA_APPEND, dataAppend),
            3, "Data Append");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes the secified user mapping file. The default directory is set
/// HIFN  using command MMEM:CDIRectory. A path can also be specified, in which
/// HIFN  case the files in the specified directory are read. The file extension
/// HIFN  may be omitted. Only files with the file extension *.vam will be
/// HIFN  deleted.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR fileName/File name parameter is a string. It completes the file path and file
/// HIPAR fileName/name with extention (*.wv).
ViStatus _VI_FUNC rssmxv_DeleteDMMappingList(ViSession instrSession,
                                             ViInt32   path,
                                             ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DM_MAPPING_LIST_DELETE, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes the selected file with Custom Digital Modulation settings. The
/// HIFN  folder is set using command MMEM:CDIRectory. A path can also be
/// HIFN  specified, in which case the files in the specified folder are read.
/// HIFN  The file extension may be omitted. Only files with the file extension
/// HIFN  *.dm_stu will be deleted.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR fileName/File name parameter is a string. It completes the file path and file
/// HIPAR fileName/name with extention (*.wv).
ViStatus _VI_FUNC rssmxv_DeleteDMUserStandards(ViSession instrSession,
                                               ViInt32   path,
                                               ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DM_DELETE_USER_STANDARDS, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Loads the selected file with Custom Digital Modulation settings. The
/// HIFN  folder is set using command MMEM:CDIRectory. A path can also be
/// HIFN  specified, in which case the files in the specified folder are read.
/// HIFN  The file extension may be omitted. Only files with the file extension
/// HIFN  *.dm_stu will be deleted.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR fileName/File name parameter is a string. It completes the file path and file
/// HIPAR fileName/name with extention (*.wv).
ViStatus _VI_FUNC rssmxv_LoadDMUserStandards(ViSession instrSession,
                                             ViInt32   path,
                                             ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DM_LOAD_USER_STANDARDS, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Loads the selected file with Custom Digital Modulation settings. The
/// HIFN  folder is set using command MMEM:CDIRectory. A path can also be
/// HIFN  specified, in which case the files in the specified folder are read.
/// HIFN  The file extension may be omitted. Only files with the file extension
/// HIFN  *.dm_stu will be deleted.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR fileName/File name parameter is a string. It completes the file path and file
/// HIPAR fileName/name with extention (*.wv).
ViStatus _VI_FUNC rssmxv_SaveDMUserStandards(ViSession instrSession,
                                             ViInt32   path,
                                             ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_DM_STORE_USER_STANDARDS, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sets the baseband to that the channel is mapped.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR channel/Sets the channel number. Up to 8 channels per HS DIG I/Q interface and
/// HIPAR channel/max. 8 channels for both interfaces.
/// HIPAR activateChannel/Activates the channel.
/// HIPAR bbChannel/This control is reserved
ViStatus _VI_FUNC rssmxv_ConfigureBBINChannelMapping(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   channel,
                                                     ViBoolean activateChannel,
                                                     ViInt32   bbChannel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_Channel[RS_REPCAP_BUF_SIZE] = "";
             bbChannel;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSSMXV_ATTR_BBIN_ACTIVATE_CHANNEL,
            "Path", path - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Path");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSSMXV_ATTR_BBIN_ACTIVATE_CHANNEL,
            "BBINChannel", channel , RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "%s,%s", repCap, repCap_Channel);

    viCheckParm(rssmxv_SetAttributeViBoolean(instrSession, repCap, RSSMXV_ATTR_BBIN_ACTIVATE_CHANNEL, activateChannel),
            4, "Activate Channel");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function sets the peak level per channel relative to full scale
/// HIFN  and crest factor of the individual channels.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR channel/Sets the channel number. Up to 8 channels per HS DIG I/Q interface and
/// HIPAR channel/max. 8
/// HIPAR crestFactor/Sets the crest factor of the individual channels.
/// HIPAR peakLevel/Sets the peak level per channel relative to full scale.
ViStatus _VI_FUNC rssmxv_QueryBBINChannelPower(ViSession instrSession,
                                               ViInt32   path,
                                               ViInt32   channel,
                                               ViReal64* crestFactor,
                                               ViReal64* peakLevel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_Channel[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSSMXV_ATTR_BBIN_CHANNEL_CREST_FACTOR,
            "Path", path - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Path");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSSMXV_ATTR_BBIN_CHANNEL_CREST_FACTOR,
            "BBINChannel", channel , RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "%s,%s", repCap, repCap_Channel);

    viCheckParm(rssmxv_GetAttributeViReal64(instrSession, repCap, RSSMXV_ATTR_BBIN_CHANNEL_CREST_FACTOR, crestFactor),
            4, "Crest Factor");

    viCheckParm(rssmxv_GetAttributeViReal64(instrSession, repCap, RSSMXV_ATTR_BBIN_CHANNEL_PEAK_LEVEL, peakLevel),
            5, "Peak Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the signal generator's reference oscillator.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR source/This function selects between internal and external reference
/// HIPAR source/frequency.
/// HIPAR frequency/Sets the reference oscillator frequency.
ViStatus _VI_FUNC rssmxv_ConfigureReferenceOscillator(ViSession instrSession,
                                                      ViInt32   source,
                                                      ViInt32   frequency)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_SetAttributeViInt32(instrSession, "", RSSMXV_ATTR_REFERENCE_OSCILLATOR_SOURCE, source),
            2, "Source");

    viCheckParm(rssmxv_SetAttributeViInt32(instrSession, "", RSSMXV_ATTR_REFERENCE_OSCILLATOR_EXTERNAL_FREQUENCY, frequency),
            3, "Frequency");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the frequency of the RF output signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR frequency/Sets the frequency of the RF output signal for CW mode
/// HIPAR frequency/(:SOURce:FREQuency:MODE CW). In Sweep mode (:SOURce:FREQuency:MODE
/// HIPAR frequency/SWEep), this value is linked to the current sweep frequency.
ViStatus _VI_FUNC rssmxv_ConfigureRFFrequency(ViSession instrSession,
                                              ViInt32   path,
                                              ViReal64  frequency)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViReal64(instrSession, repCap, RSSMXV_ATTR_RF_FREQUENCY, frequency),
            3, "Frequency");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the signal generator LF sweep mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR mode/This control sets the mode.
ViStatus _VI_FUNC rssmxv_ConfigureLFSweep(ViSession instrSession,
                                          ViInt32   path,
                                          ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViInt32(instrSession, repCap, RSSMXV_ATTR_FREQUENCY_SWEEP_MODE, mode),
            3, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function configures the start and stop frequencies for a LF
/// HIFN  frequency sweep. If the stop frequency is less than the start
/// HIFN  frequency, the frequency decreases during the sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR start/Sets the start frequency for the LF Sweep mode.
/// HIPAR stop/Sets the stop frequency for the LF sweep.
ViStatus _VI_FUNC rssmxv_ConfigureLFFrequencySweepStartStop(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViReal64  start,
                                                            ViReal64  stop)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViReal64(instrSession, repCap, RSSMXV_ATTR_FREQUENCY_SWEEP_START_FREQUENCY, start),
            3, "Start");

    viCheckParm(rssmxv_SetAttributeViReal64(instrSession, repCap, RSSMXV_ATTR_FREQUENCY_SWEEP_STOP_FREQUENCY, stop),
            4, "Stop");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function configures the settings that control the step
/// HIFN  frequencies of the generator's RF output signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR scaling/Selects linear or logarithmic sweep spacing.
/// HIPAR stepSize/Sets the step size.
ViStatus _VI_FUNC rssmxv_ConfigureFrequencyStep(ViSession instrSession,
                                                ViInt32   path,
                                                ViInt32   scaling,
                                                ViReal64  stepSize)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViAttr   attribute = 0;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViInt32(instrSession, repCap, RSSMXV_ATTR_FREQUENCY_SWEEP_SPACING, scaling),
            3, "Scaling");

    switch (scaling)
    {
    case RSSMXV_VAL_FREQ_SWEEP_SPACING_LINEAR:
        attribute = RSSMXV_ATTR_FREQUENCY_SWEEP_STEP_LINEAR;
        break;

    case RSSMXV_VAL_FREQ_SWEEP_SPACING_LOGARITHMIC:
        attribute = RSSMXV_ATTR_FREQUENCY_SWEEP_STEP_LOG;
        break;

    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, scaling), 3, "Scaling");
        break;
    }

    if (attribute != 0)
    {
        viCheckParm(rssmxv_SetAttributeViReal64(instrSession, repCap, attribute, stepSize),
                4, "Step Size");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function configures how the frequency sweep advances.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR dwell/Sets the time taken for each frequency step of the sweep.
ViStatus _VI_FUNC rssmxv_ConfigureFrequencyStepDwell(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViReal64  dwell)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViReal64(instrSession, repCap, RSSMXV_ATTR_FREQUENCY_SWEEP_DWELL_TIME, dwell),
            3, "Dwell");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates the RF output signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR outputEnabled/Activates the RF output signal.
ViStatus _VI_FUNC rssmxv_ConfigureOutputEnabled(ViSession instrSession,
                                                ViInt32   path,
                                                ViBoolean outputEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViBoolean(instrSession, repCap, RSSMXV_ATTR_OUTPUT_ENABLED, outputEnabled),
            3, "Output Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the power level of the RF output signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR powerLevel/Sets the RF output level in CW mode.
ViStatus _VI_FUNC rssmxv_ConfigureRFAmplitude(ViSession instrSession,
                                              ViInt32   path,
                                              ViReal64  powerLevel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViReal64(instrSession, repCap, RSSMXV_ATTR_RF_AMPLITUDE, powerLevel),
            3, "Power Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function sets RF level main  parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR mode/This control is reserved.
/// HIPAR settingCharacteristics/Selects the level behavior at the RF output over time.
/// HIPAR limit/Limits the maximum RF output level in CW and SWEEP mode. It does not
/// HIPAR limit/influence the LEVEL display or the response to the POW? query command.
/// HIPAR offset/Specifies the constant level offset of a downstream
/// HIPAR offset/attenuator/amplifier.
ViStatus _VI_FUNC rssmxv_ConfigureRFLevel(ViSession instrSession,
                                          ViInt32   path,
                                          ViInt32   mode,
                                          ViInt32   settingCharacteristics,
                                          ViReal64  limit,
                                          ViReal64  offset)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
             mode;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViInt32(instrSession, repCap, RSSMXV_ATTR_RF_LEVEL_SETTING_CHARACTERISTICS, settingCharacteristics),
            4, "Setting Characteristics");

    viCheckParm(rssmxv_SetAttributeViReal64(instrSession, repCap, RSSMXV_ATTR_RF_LEVEL_LIMIT, limit),
            5, "Limit");

    viCheckParm(rssmxv_SetAttributeViReal64(instrSession, repCap, RSSMXV_ATTR_RF_LEVEL_OFFSET, offset),
            6, "Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the RF level attenuator.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR mode/Switches the mode of the attenuator at the RF output (Attenuator
/// HIPAR mode/MODe).
/// HIPAR rfOFFMode/Selects the attenuator's state after the RF signal is switched off.
ViStatus _VI_FUNC rssmxv_ConfigureRFLevelAttenuator(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViInt32   mode,
                                                    ViInt32   rfOFFMode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViInt32(instrSession, repCap, RSSMXV_ATTR_LEVEL_SWEEP_ATTENUATOR_MODE, mode),
            3, "Mode");

    viCheckParm(rssmxv_SetAttributeViInt32(instrSession, repCap, RSSMXV_ATTR_RF_ATTENUATOR_RF_OFF_MODE, rfOFFMode),
            5, "RF OFF Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Selects the power sensor used for power control.
///HIRET Returns the status code of this operation.
///HIPAR sense/Selects repeated capability Sense.
///HIPAR powerSensor/Selects the power sensor used for power control.
ViStatus _VI_FUNC rssmxv_SelectPowerSensor(ViSession instrSession,
                                           ViInt32   sense,
                                           ViInt32   powerSensor)
{
    ViStatus error = VI_SUCCESS;
    ViChar   senseRepCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  senseCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Sense", &senseCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, sense, 1, senseCount),
            2, "Sense");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSSMXV_ATTR_POWER_SENSOR_CONTROL_SELECT,
        "Sense", sense - 1, RS_REPCAP_BUF_SIZE, senseRepCap), 2 ,"Sense");

    viCheckParm(rssmxv_SetAttributeViInt32(instrSession, senseRepCap, RSSMXV_ATTR_POWER_SENSOR_CONTROL_SELECT, powerSensor),
            3, "Power Sensor");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Queries the reference level of the user correction.
///HIRET Returns the status code of this operation.
///HIPAR path/Selects the path.
///HIPAR reference/Queries the reference level of the user correction.
ViStatus _VI_FUNC rssmxv_QueryRFLevelReference(ViSession instrSession,
                                               ViInt32   path,
                                               ViReal64  *reference)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  pathCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Path", &pathCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, path, 1, pathCount),
            2, "Path");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSSMXV_ATTR_RF_LEVEL_REFERENCE,
            "Path", path - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Path");

    viCheckParm(rssmxv_GetAttributeViReal64(instrSession, repCap, RSSMXV_ATTR_RF_LEVEL_REFERENCE, reference),
            3, "Reference");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines the state of the RF output signal when the instrument is switched on.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR powerOnState/Selects the state which the RF output assumes when the instrument is
/// HIPAR powerOnState/switched on.
ViStatus _VI_FUNC rssmxv_ConfigurePowerOnEMF(ViSession instrSession,
                                             ViInt32   path,
                                             ViInt32   powerOnState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViInt32(instrSession, repCap, RSSMXV_ATTR_POWER_ON_STATE, powerOnState),
            3, "Power On State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function configures the frequency and power mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR frequencyMode/Sets the frequency mode for generating the RF output signal in the
/// HIPAR frequencyMode/selected path. The selected mode determines the parameters to be used
/// HIPAR frequencyMode/for further frequency settings.
/// HIPAR powerMode/Selects the operating mode of the instrument to set the output level.
ViStatus _VI_FUNC rssmxv_ConfigureFrequencyAndPowerMode(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   frequencyMode,
                                                        ViInt32   powerMode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmxv_SetAttributeViInt32(instrSession, repCap, RSSMXV_ATTR_RF_FREQUENCY_MODE, frequencyMode),
            3, "Frequency Mode");

    viCheckParm(rssmxv_SetAttributeViInt32(instrSession, repCap, RSSMXV_ATTR_RF_POWER_MODE, powerMode),
            4, "Power Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enters the frequency value in the table selected with
/// HIFN  RSSMXV_ATTR_USER_CORRECTION_DATA_TABLE.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path.
/// HIPAR arraySize/Sets the array size.
/// HIPAR frequencies/Enters the frequency values.
ViStatus _VI_FUNC rssmxv_ConfigureUserCorrectionFrequencyValues(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   arraySize,
                            ViReal64  frequencies[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViString param = NULL;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    checkErr(RsCore_Convert_ViReal64array_To_String(instrSession, frequencies, arraySize, NULL, &param));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_HIDDEN_USER_CORRECTION_DATA_FREQUENCY_VALUES, param),
            4, "Frequencies");

Error:
    if (param) free (param);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the frequency value in the table selected with
/// HIFN  RSSMXV_ATTR_USER_CORRECTION_DATA_TABLE.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path.
/// HIPAR arraySize/Sets the array size.
/// HIPAR frequencies/Returns the frequency values.
/// HIPAR valuesRead/Returns the number of values read.
ViStatus _VI_FUNC rssmxv_QueryUserCorrectionFrequencyValues(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViInt32   arraySize,
                                                            ViReal64  frequencies[],
                                                            ViInt32   *valuesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  pathCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Path", &pathCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, path, 1, pathCount),
            2, "Path");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSSMXV_ATTR_HIDDEN_USER_CORRECTION_DATA_FREQUENCY_VALUES,
            "Path", path - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Path");
    viCheckParm(RsCore_GetAttributeViStringAsViReal64ArrayToUserBuffer(instrSession, repCap, RSSMXV_ATTR_HIDDEN_USER_CORRECTION_DATA_FREQUENCY_VALUES, NULL, arraySize, frequencies, valuesRead),
        4, "Frequencies");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enters the level values to the selected table.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path.
/// HIPAR arraySize/Sets the array size.
/// HIPAR levels/Enters the level values to the selected table.
ViStatus _VI_FUNC rssmxv_ConfigureUserCorrectionLevelValues(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViInt32   arraySize,
                                                            ViReal64  levels[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViString param = NULL;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    checkErr(RsCore_Convert_ViReal64array_To_String(instrSession, levels, arraySize, NULL, &param));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_HIDDEN_USER_CORRECTION_DATA_LEVEL_VALUES, param),
            4, "Levels");

Error:
    if (param) free (param);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the level values from the selected table.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path.
/// HIPAR arraySize/Sets the array size.
/// HIPAR levels/Returns the level values from the selected table.
/// HIPAR valuesRead/Returns the number of values read.
ViStatus _VI_FUNC rssmxv_QueryUserCorrectionLevelValues(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   arraySize,
                                                        ViReal64  levels[],
                                                        ViInt32   *valuesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  pathCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Path", &pathCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, path, 1, pathCount),
            2, "Path");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSSMXV_ATTR_HIDDEN_USER_CORRECTION_DATA_LEVEL_VALUES,
            "Path", path - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Path");
    viCheckParm(RsCore_GetAttributeViStringAsViReal64ArrayToUserBuffer(instrSession, repCap, RSSMXV_ATTR_HIDDEN_USER_CORRECTION_DATA_LEVEL_VALUES, NULL, arraySize, levels, valuesRead),
        4, "Frequencies");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enters the dwell time values in the selected list in s.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path.
/// HIPAR arraySize/Sets the array size.
/// HIPAR dwellTimes/Enters the dwell time values in the selected list in s.
ViStatus _VI_FUNC rssmxv_ConfigureListDwellTimeValues(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32   arraySize,
                                                      ViReal64  dwellTimes[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViString param = NULL;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    checkErr(RsCore_Convert_ViReal64array_To_String(instrSession, dwellTimes, arraySize, NULL, &param));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_HIDDEN_LIST_DWELL_TIME_VALUES, param),
            4, "Dwell Times");

Error:
    if (param) free (param);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the dwell time values in the selected list in s.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path.
/// HIPAR arraySize/Sets the array size.
/// HIPAR dwellTimes/Returns the dwell time values in the selected list in s.
/// HIPAR valuesRead/Returns the number of values read.
ViStatus _VI_FUNC rssmxv_QueryListDwellTimeValues(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViInt32   arraySize,
                                                  ViReal64  dwellTimes[],
                                                  ViInt32   *valuesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  pathCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Path", &pathCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, path, 1, pathCount),
            2, "Path");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSSMXV_ATTR_HIDDEN_LIST_DWELL_TIME_VALUES,
            "Path", path - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Path");
    viCheckParm(RsCore_GetAttributeViStringAsViReal64ArrayToUserBuffer(instrSession, repCap, RSSMXV_ATTR_HIDDEN_LIST_DWELL_TIME_VALUES, NULL, arraySize, dwellTimes, valuesRead),
        4, "Dwell Times");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enters the frequency values in the selected list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path.
/// HIPAR arraySize/Sets the array size.
/// HIPAR frequencies/Enters the frequency values in the selected list.
ViStatus _VI_FUNC rssmxv_ConfigureListFrequencyValues(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32   arraySize,
                                                      ViReal64  frequencies[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViString param = NULL;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    checkErr(RsCore_Convert_ViReal64array_To_String(instrSession, frequencies, arraySize, NULL, &param));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_HIDDEN_LIST_FREQUENCY_VALUES, param),
            4, "Frequencies");

Error:
    if (param) free (param);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the frequency values in the selected list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path.
/// HIPAR arraySize/Sets the array size.
/// HIPAR frequencies/Returns the frequency values in the selected list.
/// HIPAR valuesRead/Returns the number of values read.
ViStatus _VI_FUNC rssmxv_QueryListFrequencyValues(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViInt32   arraySize,
                                                  ViReal64  frequencies[],
                                                  ViInt32   *valuesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  pathCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Path", &pathCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, path, 1, pathCount),
            2, "Path");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSSMXV_ATTR_HIDDEN_LIST_FREQUENCY_VALUES,
            "Path", path - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Path");
    viCheckParm(RsCore_GetAttributeViStringAsViReal64ArrayToUserBuffer(instrSession, repCap, RSSMXV_ATTR_HIDDEN_LIST_FREQUENCY_VALUES, NULL, arraySize, frequencies, valuesRead),
        4, "Frequencies");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enters the power values in the selected list. The number of level
/// HIFN  values must correspond to the number of frequency values. Existing data
/// HIFN  is overwritten.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path.
/// HIPAR arraySize/Sets the array size.
/// HIPAR powers/Enters the power values in the selected list. The number of power
/// HIPAR powers/values must correspond to the number of frequency values. Existing data
/// HIPAR powers/is overwritten.
ViStatus _VI_FUNC rssmxv_ConfigureListPowerValues(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViInt32   arraySize,
                                                  ViReal64  powers[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViString param = NULL;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_pathRepCap(instrSession, path, repCap));

    checkErr(RsCore_Convert_ViReal64array_To_String(instrSession, powers, arraySize, NULL, &param));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, repCap, RSSMXV_ATTR_HIDDEN_LIST_POWER_VALUES, param),
            4, "Powers");

Error:
    if (param) free (param);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the power values in the selected list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the path.
/// HIPAR arraySize/Sets the array size.
/// HIPAR powerValues/Returns the power values in the selected list.
/// HIPAR valuesRead/Returns the number of values read.
ViStatus _VI_FUNC rssmxv_QueryListPowerValues(ViSession instrSession,
                                              ViInt32   path,
                                              ViInt32   arraySize,
                                              ViReal64  powerValues[],
                                              ViInt32   *valuesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  pathCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Path", &pathCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, path, 1, pathCount),
            2, "Path");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSSMXV_ATTR_HIDDEN_LIST_POWER_VALUES,
            "Path", path - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Path");
    viCheckParm(RsCore_GetAttributeViStringAsViReal64ArrayToUserBuffer(instrSession, repCap, RSSMXV_ATTR_HIDDEN_LIST_POWER_VALUES, NULL, arraySize, powerValues, valuesRead),
        4, "Frequencies");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Assigns a sensor directly to one of the sensor channels, using the
/// HIFN  sensor name and serial number. To find out the sensor name and ID,
/// HIFN  you can get it from the label of the R&S NRP, or using the command
/// HIFN  :SLISt:SCAN[:STATe]. This command detects all R&S NRP power sensors
/// HIFN  connected in the LAN or via USBTMC protocol.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR sensorID/Sets the sensor ID.
/// HIPAR mapping/Sets the Power Sensor Mapping for selected sensor.
ViStatus _VI_FUNC rssmxv_ConfigurePowerSensorMappingDirectly(ViSession instrSession,
                                                             ViString  sensorID,
                                                             ViInt32   mapping)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2string;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, mapping, RSSMXV_VAL_POWER_SENSOR_MAPPING_SENSOR1, RSSMXV_VAL_POWER_SENSOR_MAPPING_UNMAPPED),
            3, "Mapping");
    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsSMxV_rngPowerSensorMapping,
                    mapping, &p2string), 3, "Mapping");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":SLIS:SENS:MAP '%s',%s", sensorID, p2string);
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Scans for R&S NRP power sensors connected over a USB interface.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serial/Sets the Serial number.
/// HIPAR deviceID/Sets the Device ID number.
ViStatus _VI_FUNC rssmxv_ConfigurePowerSensorScanUSB(ViSession instrSession,
                                                     ViInt32   serial,
                                                     ViInt32   deviceID)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":SLIS:SCAN:USEN %ld,%ld", serial, deviceID);
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


///HINF  Starts power control using the selected sensor. The control
///HINF  loop periodically adjusts the output level of the signal
///HINF  generator. After switching off, the running loop is completed.
///HIRET Returns the status code of this operation.
///HIPAR sense/Selects repeated capability Sense.
///HIPAR powerSensorControl/Starts power control using the selected
///HIPAR powerSensorControl/sensor. The control loop periodically adjusts
///HIPAR powerSensorControl/the output level of the signal generator.
///HIPAR powerSensorControl/After switching off, the running loop is
///HIPAR powerSensorControl/completed.
ViStatus _VI_FUNC rssmxv_ConfigurePowerSensorControlEnabled(ViSession instrSession,
                                                            ViInt32   sense,
                                                            ViBoolean powerSensorControl)
{
    ViStatus error = VI_SUCCESS;
    ViChar   senseRepCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  senseCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Sense", &senseCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, sense, 1, senseCount),
            2, "Sense");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSSMXV_ATTR_POWER_SENSOR_CONTROL_ENABLED,
        "Sense", sense - 1, RS_REPCAP_BUF_SIZE, senseRepCap), 2 ,"Sense");

    viCheckParm(rssmxv_SetAttributeViBoolean(instrSession, senseRepCap, RSSMXV_ATTR_POWER_SENSOR_CONTROL_ENABLED, powerSensorControl),
            3, "Power Sensor Control");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Selects the measurement mode for the power sensor.
///HIRET Returns the status code of this operation.
///HIPAR sense/Selects repeated capability Sense.
///HIPAR mode/Selects the measurement mode for the power sensor.
ViStatus _VI_FUNC rssmxv_ConfigurePowerSensorControlMode(ViSession instrSession,
                                                         ViInt32   sense,
                                                         ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   senseRepCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  senseCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Sense", &senseCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, sense, 1, senseCount),
            2, "Sense");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSSMXV_ATTR_POWER_SENSOR_CONTROL_MODE,
        "Sense", sense - 1, RS_REPCAP_BUF_SIZE, senseRepCap), 2 ,"Sense");

    viCheckParm(rssmxv_SetAttributeViInt32(instrSession, senseRepCap, RSSMXV_ATTR_POWER_SENSOR_CONTROL_MODE, mode),
            3, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Triggers the power sensor to measure the power value once.
///HIRET Returns the status code of this operation.
///HIPAR sense/Selects repeated capability Sense.
ViStatus _VI_FUNC rssmxv_PowerSensorControlExecuteSingle(ViSession instrSession,
                                                         ViInt32   sense)
{
    ViStatus error = VI_SUCCESS;
    ViChar   senseRepCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  senseCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Sense", &senseCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, sense, 1, senseCount),
            2, "Sense");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSSMXV_ATTR_POWER_SENSOR_CONTROL_EXECUTE_SINGLE,
        "Sense", sense - 1, RS_REPCAP_BUF_SIZE, senseRepCap), 2 ,"Sense");

    checkErr(rssmxv_SetAttributeViString(instrSession, senseRepCap, RSSMXV_ATTR_POWER_SENSOR_CONTROL_EXECUTE_SINGLE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Configures delay and capture range for the measurement.
///HIRET Returns the status code of this operation.
///HIPAR sense/Selects repeated capability Sense.
///HIPAR delay/Sets a waiting time for the generator to adjust the
///HIPAR delay/output level. After the delay time has elapsed, the power
///HIPAR delay/sensor measures the next value.
///HIPAR range/Defines the capture range of the power control system.
ViStatus _VI_FUNC rssmxv_ConfigurePowerSensorControlMeasurementSettings(
                            ViSession instrSession,
                            ViInt32   sense,
                            ViInt32   delay,
                            ViReal64  range)
{
    ViStatus error = VI_SUCCESS;
    ViChar   senseRepCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  senseCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Sense", &senseCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, sense, 1, senseCount),
            2, "Sense");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSSMXV_ATTR_POWER_SENSOR_CONTROL_DELAY,
        "Sense", sense - 1, RS_REPCAP_BUF_SIZE, senseRepCap), 2 ,"Sense");

    viCheckParm(rssmxv_SetAttributeViInt32(instrSession, senseRepCap, RSSMXV_ATTR_POWER_SENSOR_CONTROL_DELAY, delay),
            3, "Delay");

    viCheckParm(rssmxv_SetAttributeViReal64(instrSession, senseRepCap, RSSMXV_ATTR_POWER_SENSOR_CONTROL_CATCH_RANGE, range),
            4, "Range");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Activates power control by means of the peak power values,
///HINF  provided the power sensor supports this function.
///HIRET Returns the status code of this operation.
///HIPAR sense/Selects repeated capability Sense.
///HIPAR peak/Activates power control by means of the peak power
///HIPAR peak/values, provided the power sensor supports this function.
ViStatus _VI_FUNC rssmxv_ConfigurePowerSensorControlPeakEnabled(
                            ViSession instrSession,
                            ViInt32   sense,
                            ViBoolean peak)
{
    ViStatus error = VI_SUCCESS;
    ViChar   senseRepCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  senseCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Sense", &senseCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, sense, 1, senseCount),
            2, "Sense");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSSMXV_ATTR_POWER_SENSOR_CONTROL_PEAK_ENABLED,
        "Sense", sense - 1, RS_REPCAP_BUF_SIZE, senseRepCap), 2 ,"Sense");

    viCheckParm(rssmxv_SetAttributeViBoolean(instrSession, senseRepCap, RSSMXV_ATTR_POWER_SENSOR_CONTROL_PEAK_ENABLED, peak),
            3, "Peak");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Sets the target level required at the DUT. To define the unit
///HINF  of the power value, use command RSSMXV_ATTR_UNIT_POWER.
///HIRET Returns the status code of this operation.
///HIPAR sense/Selects repeated capability Sense.
///HIPAR targetLevel/Sets the target level required at the DUT. To
///HIPAR targetLevel/define the unit of the power value, use command
///HIPAR targetLevel/RSSMXV_ATTR_UNIT_POWER.
ViStatus _VI_FUNC rssmxv_ConfigurePowerSensorControlTargetLevel(
                            ViSession instrSession,
                            ViInt32   sense,
                            ViReal64  targetLevel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   senseRepCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  senseCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Sense", &senseCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, sense, 1, senseCount),
            2, "Sense");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSSMXV_ATTR_POWER_SENSOR_CONTROL_TARGET_LEVEL,
        "Sense", sense - 1, RS_REPCAP_BUF_SIZE, senseRepCap), 2 ,"Sense");

    viCheckParm(rssmxv_SetAttributeViReal64(instrSession, senseRepCap, RSSMXV_ATTR_POWER_SENSOR_CONTROL_TARGET_LEVEL, targetLevel),
            3, "Target Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Sets the measured power value as reference level.
///HIRET Returns the status code of this operation.
///HIPAR sense/Selects repeated capability Sense.
ViStatus _VI_FUNC rssmxv_PowerSensorControlMeasureAsTargetLevel(
                            ViSession instrSession,
                            ViInt32   sense)
{
    ViStatus error = VI_SUCCESS;
    ViChar   senseRepCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  senseCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Sense", &senseCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, sense, 1, senseCount),
            2, "Sense");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSSMXV_ATTR_POWER_SENSOR_CONTROL_MEASURE_AS_TARGET_LEVEL,
        "Sense", sense - 1, RS_REPCAP_BUF_SIZE, senseRepCap), 2 ,"Sense");

    checkErr(rssmxv_SetAttributeViString(instrSession, senseRepCap, RSSMXV_ATTR_POWER_SENSOR_CONTROL_MEASURE_AS_TARGET_LEVEL, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries information on the modules available in the instrument, using
/// HIFN  the variant and revision state.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR moduleName/Module name, as queried with the command
/// HIPAR moduleName/:DIAGnostic<hw>:BGINfo:CATalog?.
/// HIPAR arraySize/Sets the array size.
/// HIPAR info/Queries information on the modules available in the instrument, using
/// HIPAR info/the variant and revision state.
ViStatus _VI_FUNC rssmxv_DiagnosticModulesInfo(ViSession instrSession,
                                               ViInt32   path,
                                               ViString  moduleName,
                                               ViInt32   arraySize,
                                               ViChar    info[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, path, 1, 1),
            2, "Path");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":DIAG%ld:BGIN? '%s'", path, moduleName);
    checkErr(rssmxv_QueryViString(instrSession, cmd, arraySize, info));

    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Triggers the voltage measurement at the specified test point and
/// HIFN  returns the measured voltage.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR pointName/Test point name, as queried with the command
/// HIPAR pointName/:DIAGnostic<hw>:POINt:CATalog?
/// HIPAR arraySize/Sets the array size.
/// HIPAR info/Triggers the voltage measurement at the specified test point and
/// HIPAR info/returns the measured voltage.
ViStatus _VI_FUNC rssmxv_DiagnosticTestPoint(ViSession instrSession,
                                             ViInt32   path,
                                             ViString  pointName,
                                             ViInt32   arraySize,
                                             ViChar    info[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, path, 1, 1),
            2, "Path");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":DIAG%ld:POIN? '%s'", path, pointName);
    checkErr(rssmxv_QueryViString(instrSession, cmd, arraySize, info));

    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


///HINF  Sets the brightness of the dispaly.
///HIRET Returns the status code of this operation.
///HIPAR brightness/Sets the brightness of the dispaly.
ViStatus _VI_FUNC rssmxv_ConfigureDisplayBrightness(ViSession instrSession,
                                                    ViReal64  brightness)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_SetAttributeViReal64(instrSession, NULL, RSSMXV_ATTR_DISPLAY_BRIGHTNESS, brightness),
            2, "Brightness");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Sets the brightness of the [RF on/off] key.
///HIRET Returns the status code of this operation.
///HIPAR buttonBrightness/Sets the brightness of the [RF on/off] key.
ViStatus _VI_FUNC rssmxv_ConfigureDisplayButtonBrightness(ViSession instrSession,
                                                          ViReal64  buttonBrightness)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_SetAttributeViReal64(instrSession, NULL, RSSMXV_ATTR_DISPLAY_BUTTON_BRIGHTNESS, buttonBrightness),
            2, "Button Brightness");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}



///HINF  Turns the HUMS service and data collection on and off.
///HIRET Returns the status code of this operation.
///HIPAR hums/Turns the HUMS service and data collection on and off.
ViStatus _VI_FUNC rssmxv_ConfigureHUMSEnabled(ViSession instrSession,
                                              ViBoolean hums)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_SetAttributeViBoolean(instrSession, NULL, RSSMXV_ATTR_HUMS_ENABLED, hums),
            2, "HUMS");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Selects  the format for the queried HUMS data. You can query
///HINF  the HUMS data either in JSON format or XML format.
///HIRET Returns the status code of this operation.
///HIPAR dataFormat/Selects  the format for the queried HUMS data. You
///HIPAR dataFormat/can query the HUMS data either in JSON format or
///HIPAR dataFormat/XML format.
ViStatus _VI_FUNC rssmxv_ConfigureHUMSDataFormat(ViSession instrSession,
                                                 ViInt32   dataFormat)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_SetAttributeViInt32(instrSession, NULL, RSSMXV_ATTR_HUMS_DATA_FORMAT, dataFormat),
            2, "Data Format");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Deletes the complete HUMS data. This includes device history,
///HINF  device tags, SCPI connections, utilization history and
///HINF  utilizations.
///HIRET Returns the status code of this operation.
ViStatus _VI_FUNC rssmxv_DeleteHUMSAllData(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_SetAttributeViString(instrSession, NULL, RSSMXV_ATTR_HUMS_DELETE_ALL_DATA, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Queries the device history information of the connected
///HINF  instrument. Depending on the set data format, the queried data is
///HINF  either displayed in XML or JSON format. For more information
///HINF  about setting the data format, see RSSMXV_ATTR_HUMS_DATA_FORMAT.
///HIRET Returns the status code of this operation.
///HIPAR bufferSize/Size of output array.
///HIPAR history/Queries the device history information of the
///HIPAR history/connected instrument. Depending on the set data format, the
///HIPAR history/queried data is either displayed in XML or JSON format.
///HIPAR history/For more information about setting the data format, see
///HIPAR history/RSSMXV_ATTR_HUMS_DATA_FORMAT.
///HIPAR bytesRead/Returns bytes read from the instrument.
ViStatus _VI_FUNC rssmxv_ExportHUMSHistory(ViSession instrSession,
                                           ViInt32   bufferSize,
                                           ViChar    history[],
                                           ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_GetAttributeViStringWithRealLen(instrSession, NULL, RSSMXV_ATTR_HUMS_EXPORT_HISTORY,
        bufferSize, history, bytesRead), 3, "History");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Saves the HUMS history as a ZIP file to your preferred path.
///HIRET Returns the status code of this operation.
///HIPAR filename/Saves the HUMS history as a ZIP file to your
///HIPAR filename/preferred path.
ViStatus _VI_FUNC rssmxv_ExportHUMSHistoryToFile(ViSession instrSession,
                                                 ViString  filename)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, NULL, RSSMXV_ATTR_HUMS_EXPORT_HISTORY_TO_FILE, filename),
            2, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Deletes the complete device history information of the
///HINF  connected instrument.
///HIRET Returns the status code of this operation.
ViStatus _VI_FUNC rssmxv_DeleteHUMSHistory(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_SetAttributeViString(instrSession, NULL, RSSMXV_ATTR_HUMS_DELETE_HISTORY, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Queries all key-value tags that you have assigend to the
///HINF  instrument. Depending on the set data format, the queried data is
///HINF  either displayed in XML or JSON format. For more information
///HINF  about setting the data format, see RSSMXV_ATTR_HUMS_DATA_FORMAT.
///HIRET Returns the status code of this operation.
///HIPAR bufferSize/Size of output array.
///HIPAR deviceTagsCatalog/Queries all key-value tags that you have
///HIPAR deviceTagsCatalog/assigend to the instrument. Depending on the
///HIPAR deviceTagsCatalog/set data format, the queried data is either
///HIPAR deviceTagsCatalog/displayed in XML or JSON format. For more
///HIPAR deviceTagsCatalog/information about setting the data format, see
///HIPAR deviceTagsCatalog/RSSMXV_ATTR_HUMS_DATA_FORMAT.
///HIPAR bytesRead/Returns bytes read from the instrument.
ViStatus _VI_FUNC rssmxv_QueryHUMSDeviceTagsCatalog(ViSession instrSession,
                                                    ViInt32   bufferSize,
                                                    ViChar    deviceTagsCatalog[],
                                                    ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_GetAttributeViStringWithRealLen(instrSession, NULL, RSSMXV_ATTR_HUMS_DEVICE_TAGS_CATALOG,
        bufferSize, deviceTagsCatalog, bytesRead), 3, "Device Tags Catalog");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Deletes all key-value tags you have assigned to the
///HINF  instrument.
///HIRET Returns the status code of this operation.
ViStatus _VI_FUNC rssmxv_HUMSDeviceTagsDeleteAll(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_SetAttributeViString(instrSession, NULL, RSSMXV_ATTR_HUMS_DEVICE_TAGS_DELETE_ALL, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Adds or modifies a key-value pair (device tag).
///HIRET Returns the status code of this operation.
///HIPAR id/ID number of the tag you want to modify. Range of 0 - 31.
///HIPAR key/String containing key name of the tag.
///HIPAR value/String containing value of the tag.
ViStatus _VI_FUNC rssmxv_DefineHUMSDeviceTag(ViSession instrSession,
                                             ViInt32   id,
                                             ViString  key,
                                             ViString  value)
{
    ViStatus error = VI_SUCCESS;
    ViChar   param[RS_PARAM_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, id, 0, 31),
            2, "ID");

    (void)snprintf(param, RS_PARAM_BUF_SIZE, "%ld,'%s','%s'", id, key, value);

    checkErr(rssmxv_SetAttributeViString(instrSession, NULL, RSSMXV_ATTR_HIDDEN_HUMS_DEVICE_TAGS_VALUE, param));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Returns the key-value pair for a given ID or an empty string
///HINF  if the ID is unknown.
///HIRET Returns the status code of this operation.
///HIPAR tagID/ID number of the tag you want to query. Range of 0 - 31.
///HIPAR bufferSize/Size of output array.
///HIPAR key/Returns the key for the defined tag.
///HIPAR value/Returns the value for the defined tag.
///HIPAR bytesRead/Returns bytes read from the instrument.
ViStatus _VI_FUNC rssmxv_QueryHUMSDeviceTag(ViSession instrSession,
                                            ViInt32   tagID,
                                            ViInt32   bufferSize,
                                            ViChar    keyValuePair[],
                                            ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   param[RS_PARAM_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, tagID, 0, 31),
            2, "ID");

    (void)snprintf(param, bufferSize, "%ld", tagID);

    checkErr(RsCore_GetAttributeViRawStringWithQparam(instrSession, NULL, RSSMXV_ATTR_HIDDEN_HUMS_DEVICE_TAGS_VALUE, param, bufferSize, keyValuePair, bytesRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Deletes a certain tag you assigned to your instrument,
///HINF  including its key and value.
///HIRET Returns the status code of this operation.
///HIPAR tagID/Deletes a certain tag you assigned to your instrument,
///HIPAR tagID/including its key and value.
ViStatus _VI_FUNC rssmxv_DeleteHUMSDeviceTag(ViSession instrSession,
                                             ViInt32   tagID)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_SetAttributeViInt32(instrSession, NULL, RSSMXV_ATTR_HUMS_DEVICE_TAG_DELETE, tagID),
            2, "Tag ID");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Turns communication via the REST API on and off.
///HIRET Returns the status code of this operation.
///HIPAR rest/Turns communication via the REST API on and off.
ViStatus _VI_FUNC rssmxv_ConfigureSNMPRestEnabled(ViSession instrSession,
                                                  ViBoolean rest)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_SetAttributeViBoolean(instrSession, NULL, RSSMXV_ATTR_HUMS_SNMP_REST_ENABLED, rest),
            2, "Rest");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Selects the SNMP version.
///HIRET Returns the status code of this operation.
///HIPAR version/Selects the SNMP version.
ViStatus _VI_FUNC rssmxv_ConfigureSNMPVersion(ViSession instrSession,
                                              ViInt32   version)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_SetAttributeViInt32(instrSession, NULL, RSSMXV_ATTR_HUMS_SNMP_VERSION, version),
            2, "Version");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Queries the number of users and a list of all SNMP users for
///HINF  SNMPv3 (RSSMXV_ATTR_HUMS_SNMP_VERSION).).
///HIRET Returns the status code of this operation.
///HIPAR bufferSize/Size of output array.
///HIPAR userCatalog/Queries the number of users and a list of all
///HIPAR userCatalog/SNMP users for SNMPv3
///HIPAR userCatalog/(RSSMXV_ATTR_HUMS_SNMP_VERSION).).
///HIPAR bytesRead/Returns bytes read from the instrument.
ViStatus _VI_FUNC rssmxv_QuerySNMPUserCatalog(ViSession instrSession,
                                              ViInt32   bufferSize,
                                              ViChar    userCatalog[],
                                              ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_GetAttributeViStringWithRealLen(instrSession, NULL, RSSMXV_ATTR_HUMS_SNMP_USER_CATALOG,
        bufferSize, userCatalog, bytesRead), 3, "User Catalog");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Defines an SNMP user profile.
///HIRET Returns the status code of this operation.
///HIPAR name/Defines the name of the user for assigning specific user
///HIPAR name/rights. Entering a user name is mandatory.
///HIPAR access/Defines the access right for a user.
///HIPAR level/Defines the security level of the SNMP user. Depending
///HIPAR level/on the security level, the service requests user name and
///HIPAR level/passphrases for authentication and encryption.
///HIPAR authenticationPassword/Defines the password for
///HIPAR authenticationPassword/authentication. The password must have of 8 to 12
///HIPAR authenticationPassword/characters with any combination of ASCII
///HIPAR authenticationPassword/characters.
///HIPAR privacyPassword/Defines the password for encryption. This
///HIPAR privacyPassword/password must have at least 8 characters with any
///HIPAR privacyPassword/combination of ASCII characters. When
///HIPAR privacyPassword/encryption is defined, the R&S SMCV100B supports the DES
///HIPAR privacyPassword/(directed enhanced services) protocol.
ViStatus _VI_FUNC rssmxv_AddSNMPUser(ViSession instrSession,
                                     ViString  name,
                                     ViInt32   access,
                                     ViInt32   level,
                                     ViString  authenticationPassword,
                                     ViString  privacyPassword)
{
    ViStatus error = VI_SUCCESS;
    ViChar   param[RS_PARAM_BUF_SIZE] = "";
    ViChar*  p2accessCmd;
    ViChar*  p2levelCmd;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsSMxV_rngSNMPAccess, access, &p2accessCmd),
        3, "Access");
    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsSMxV_rngSNMPLevel, level, &p2levelCmd),
        4, "Level");

    switch (level)
    {
        case RSSMXV_VAL_SNMP_LEVEL_AUTHENTICATION:
            (void)snprintf(param, RS_PARAM_BUF_SIZE, "'%s',%s,%s,'%s'", name, p2accessCmd, p2levelCmd, authenticationPassword);
            break;

        case RSSMXV_VAL_SNMP_LEVEL_AUTHENTICATION_AND_PRIVACY:
            (void)snprintf(param, RS_PARAM_BUF_SIZE, "'%s',%s,%s,'%s','%s'", name, p2accessCmd, p2levelCmd, authenticationPassword, privacyPassword);
            break;

        case RSSMXV_VAL_SNMP_LEVEL_NO_AUTHENTICATION:
        default:
            (void)snprintf(param, RS_PARAM_BUF_SIZE, "'%s',%s,%s", name, p2accessCmd, p2levelCmd);
            break;
    }

    checkErr(rssmxv_SetAttributeViString(instrSession, NULL, RSSMXV_ATTR_HIDDEN_HUMS_SNMP_USER_ADD, param));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Deletes a specific SNMP user profile.
///HIRET Returns the status code of this operation.
///HIPAR username/Deletes a specific SNMP user profile.
ViStatus _VI_FUNC rssmxv_DeleteSNMPUser(ViSession instrSession,
                                        ViString  username)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, NULL, RSSMXV_ATTR_HUMS_SNMP_USER_DELETE, username),
            2, "Username");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Deletes all SNMP user profiles.
///HIRET Returns the status code of this operation.
ViStatus _VI_FUNC rssmxv_DeleteAllSNMPUsers(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_SetAttributeViString(instrSession, NULL, RSSMXV_ATTR_HUMS_SNMP_USER_DELETE_ALL, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Defines the access SNMP community strings.
///HIRET Returns the status code of this operation.
///HIPAR readOnlyAccess/Defines the SNMP community string for
///HIPAR readOnlyAccess/read-only access.
///HIPAR readWriteAccess/Defines the SNMP community string for
///HIPAR readWriteAccess/read-write access.
ViStatus _VI_FUNC rssmxv_ConfigureSNMPAccessStrings(ViSession instrSession,
                                                    ViString  readOnlyAccess,
                                                    ViString  readWriteAccess)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, NULL, RSSMXV_ATTR_HUMS_SNMP_READ_ONLY_ACCESS, readOnlyAccess),
            2, "Read Only Access");

    viCheckParm(rssmxv_SetAttributeViString(instrSession, NULL, RSSMXV_ATTR_HUMS_SNMP_READ_WRITE_ACCESS, readWriteAccess),
            3, "Read Write Access");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Defines the SNMP information for the administrator.
///HIRET Returns the status code of this operation.
///HIPAR contact/Defines the SNMP contact information for the
///HIPAR contact/administrator.
///HIPAR location/Defines the SNMP location information for the
///HIPAR location/administrator.
ViStatus _VI_FUNC rssmxv_ConfigureSNMPAdminInfo(ViSession instrSession,
                                                ViString  contact,
                                                ViString  location)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_SetAttributeViString(instrSession, NULL, RSSMXV_ATTR_HUMS_SNMP_CONTACT, contact),
            2, "Contact");

    viCheckParm(rssmxv_SetAttributeViString(instrSession, NULL, RSSMXV_ATTR_HUMS_SNMP_LOCATION, location),
            3, "Location");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Adds manually an external instrument to the list of available
/// HIFN  instruments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instrumentName/Sets the instrument name.
/// HIPAR hardwareChannel/Hardware channel (USB or LAN) used by the remote channel to the
/// HIPAR hardwareChannel/external instrument
/// HIPAR address/IP address or hostname of the connected external instrument.
/// HIPAR rfPath/Determines the number of RF paths the externa instrument is equipped
/// HIPAR rfPath/with.
ViStatus _VI_FUNC rssmxv_SystemConfigurationExternalAdd(ViSession instrSession,
                                                        ViString  instrumentName,
                                                        ViString  hardwareChannel,
                                                        ViString  address,
                                                        ViString  rfPath)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":SCON:EXT:REM:ADD \"%s\",\"%s\",\"%s\",\"%s\"\n", instrumentName,
             hardwareChannel, address, rfPath);

    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function changes the symbolic name of the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR currentName/Current name is a parameter indicating the actual name of the
/// HIPAR currentName/instrument.
/// HIPAR newName/New name is a parameter that indicats the new wanted name of the
/// HIPAR newName/instrument.
ViStatus _VI_FUNC rssmxv_SystemConfigurationExternalRename(ViSession instrSession,
                                                           ViString  currentName,
                                                           ViString  newName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SCON:EXT:REM:REN \"%s\",\"%s\"", currentName, newName);
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Select an external instrument for the selected connector.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR instrumentName/Instrument alias name.
/// HIPAR rfPath/Determines the used RF output of the external instrument.
ViStatus _VI_FUNC rssmxv_SystemConfigurationExternalHSDSelectInstrument(
                            ViSession instrSession,
                            ViString  instrumentName,
                            ViString  rfPath)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":SCON:EXT:HSD:REM:ISEL '%s','%s'", instrumentName, rfPath);
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Select an external instrument for the selected connector.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR instrumentName/Instrument alias name.
/// HIPAR path/Determines the used RF output of the external instrument.
ViStatus _VI_FUNC rssmxv_SystemConfigurationExternalHSDConnectInstrument(
                            ViSession instrSession,
                            ViString  instrumentName,
                            ViString  path)
{
    ViStatus error = VI_SUCCESS;
    ViChar   param[RS_PARAM_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    (void)snprintf(param, RS_PARAM_BUF_SIZE, "\"%s\",\"%s\"", instrumentName, path);

    checkErr(RsCore_SetAttributeViRawString(instrSession, NULL, RSSMXV_ATTR_HIDDEN_SYSTEM_CONFIGURATION_HSD_REMOTE_CONNECT_INSTRUMENT, RS_VAL_DIRECT_USER_CALL, param));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


///HINF  Queries the state and direction of HSD Remote connection.
///HIRET Returns the status code of this operation.
///HIPAR state/Queries the state of HSD Remote connection.
///HIPAR direction/Queries the connector direction.
ViStatus _VI_FUNC rssmxv_QuerySystemConfigurationExternalHSDConnectionInfo(
                            ViSession  instrSession,
                            ViBoolean* state,
                            ViInt32*   direction)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_GetAttributeViBoolean(instrSession, NULL, RSSMXV_ATTR_SYSTEM_CONFIGURATION_HSD_REMOTE_CONNECTION_STATE, state),
            2, "State");

    viCheckParm(rssmxv_GetAttributeViInt32(instrSession, NULL, RSSMXV_ATTR_SYSTEM_CONFIG_HSD_DIRECTION, direction),
            3, "Direction");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  In coupled mode, offsets the RF frequency of the external
///HINF  instrument with the selected delta value.
///HIRET Returns the status code of this operation.
///HIPAR rfFrequency/In coupled mode, offsets the RF frequency of the
///HIPAR rfFrequency/external instrument with the selected delta value.
ViStatus _VI_FUNC rssmxv_ConfigureSystemConfigurationHSDRFFrequency(
                            ViSession instrSession,
                            ViReal64  rfFrequency)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_SetAttributeViReal64(instrSession, NULL, RSSMXV_ATTR_SYSTEM_CONFIGURATION_HSD_RF_FREQ, rfFrequency),
            2, "RF Frequency");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

///HINF  Queries the name of the connected external instrument.
///HIRET Returns the status code of this operation.
///HIPAR hsd/Selects repeated capability HSD.
///HIPAR bufferSize/Size of output array.
///HIPAR name/Queries the name of the connected external instrument.
///HIPAR bytesRead/Returns bytes read from the instrument.
ViStatus _VI_FUNC rssmxv_QueryConfigurationHSDConnectorName(ViSession instrSession,
                                                            ViInt32   hsd,
                                                            ViInt32   bufferSize,
                                                            ViChar    name[],
                                                            ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   hsdRepCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  hsdCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "HSD", &hsdCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, hsd, 1, hsdCount),
            2, "HSD");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSSMXV_ATTR_SYSTEM_CONFIGURATION_CONNECTOR_HSD_NAME,
        "HSD", hsd - 1, RS_REPCAP_BUF_SIZE, hsdRepCap), 2 ,"HSD");

    viCheckParm(rssmxv_GetAttributeViStringWithRealLen(instrSession, hsdRepCap,
        RSSMXV_ATTR_SYSTEM_CONFIGURATION_CONNECTOR_HSD_NAME, bufferSize, name, bytesRead), 4, "Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function is used to read data from the instrument and write it to
/// HIFN  a user specified file on the host computer.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR source/This control selects file for the data transfer from instrument to
/// HIPAR source/control computer.
/// HIPAR destination/This control defines destination file to which the data transfer from
/// HIPAR destination/instrument to control computer applies.
ViStatus _VI_FUNC rssmxv_readToFile(ViSession instrSession,
                                    ViString  source,
                                    ViString  destination)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":MMEMory:DATA? '%s'\n", source);
    checkErr(RsCore_QueryBinaryDataBlockToFile(instrSession, cmd, destination, RS_VAL_TRUNCATE));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function is used to read data from the host computer and write it
/// HIFN  to a user specified file in the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR source/This control selects file for the data transfer from control computer
/// HIPAR source/to instrument.
/// HIPAR destination/This control defines destination file to which the data transfer from
/// HIPAR destination/control computer to instrument applies.
ViStatus _VI_FUNC rssmxv_writeFromFile(ViSession instrSession,
                                       ViString  source,
                                       ViString  destination)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":MMEM:DATA '%s',", destination);
    checkErr(RsCore_WriteBinaryDataFromFile(instrSession, cmd, source));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function resets the instrument to a known state and sends
/// HIFN  initialization commands to the instrument.  The initialization commands
/// HIFN  set instrument settings such as Headers Off, Short Command form, and
/// HIFN  Data Transfer Binary to the state necessary for the operation of the
/// HIFN  instrument driver.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a
/// HIPAR instrSession/particular instrument session.
ViStatus _VI_FUNC rssmxv_reset(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    if (RsCore_Simulating(instrSession) == VI_FALSE)
    {
        checkErr(rssmxv_ClearStatus(instrSession));
        checkErr(RsCore_Write(instrSession, "*RST")); // IGNORE: Check double write
        checkErr(RsCore_QueryViStringShort(instrSession, "*OPC?", NULL));
    }

    checkErr(rssmxv_DefaultInstrSetup(instrSession));
    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);

    return error;
}

/// HIFN This function runs the instrument's self test routine and returns the test result(s).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsscope_init or
/// HIPAR instrSession/rsscope_InitWithOptions function.
/// HIPAR testResult/Contains the value returned from the instrument self test.
/// HIPAR testMessage/Returns the self-test response string from the instrument.
ViStatus _VI_FUNC rssmxv_self_test(ViSession instrSession,
                                   ViInt16*  testResult,
                                   ViChar    testMessage[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidNullPointer(instrSession, testResult), 2, "Null address for Test Result");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, testMessage), 3, "Null address for Test Message");

    checkErr(RsCore_SelfTest(instrSession, testResult, 48, testMessage));

    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function returns the driver and instrument revisions.
/// HIRET /// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsscope_init or
/// HIPAR instrSession/rsscope_InitWithOptions function.
/// HIPAR driverRev/Returns the instrument driver software revision numbers in the form of a string.
/// HIPAR instrRev/Returns the instrument firmware revision numbers in the form of a string.
ViStatus _VI_FUNC rssmxv_revision_query(ViSession instrSession,
                                        ViChar    instrumentDriverRevision[],
                                        ViChar    firmwareRevision[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidNullPointer(instrSession, instrumentDriverRevision), 2, "Null address for Instrument Driver Revision");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, firmwareRevision), 3, "Null address for Instrument Revision");

    checkErr(RsCore_GetAttributeViString(instrSession, NULL, RS_ATTR_SPECIFIC_DRIVER_REVISION, 0, 256, instrumentDriverRevision));
    checkErr(RsCore_GetAttributeViString(instrSession, NULL, RS_ATTR_INSTRUMENT_FIRMWARE_REVISION, 0, 256, firmwareRevision));
    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function reads an error code and a message from the
/// HIFN instrument's error queue.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsscope_init or
/// HIPAR instrSession/rsscope_InitWithOptions function.
/// HIPAR errCode/Returns the error code read from the instrument's error queue.
/// HIPAR errMessage/Returns the error message string read from the instrument's error message queue.
ViStatus _VI_FUNC rssmxv_error_query(ViSession instrSession,
                                     ViInt32*  errorCode,
                                     ViChar    errorMessage[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidNullPointer(instrSession, errorCode), 2, "Null address for Error Code");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, errorMessage), 3, "Null address for Error Message");

    checkErr(RsCore_ErrorQueryAll(instrSession, errorCode, 1024, errorMessage));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns the list of static error (if any). Static errors are generally more severe than normal error conditions, which can be queried with SYSTem:ERRor[:NEXT]?.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.
/// HIPAR numberOfBytesToRead/Pass the maximum number of bytes to read from the instruments.
/// HIPAR readBuffer/After this function executes, this parameter contains the data that was read from the instrument.
/// HIPAR numBytesRead/Returns the number of bytes actually read from the instrument and stored in the Read Buffer.
ViStatus _VI_FUNC rssmxv_SystemStaticError(ViSession instrSession,
                                           ViInt32   bufferSize,
                                           ViChar    buffer[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_GetAttributeViString(instrSession, NULL, RSSMXV_ATTR_SYSTEM_STATIC_ERRORS,
            bufferSize, buffer),
            3, "Buffer");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function converts a status code returned by an instrument driver
/// HIFN  function into a user-readable string.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a
/// HIPAR instrSession/particular instrument session.
/// HIPAR errorCode/Pass the Status parameter that is returned from any of the instrument
/// HIPAR errorCode/driver functions.
/// HIPAR errorMessage/Returns the user-readable message string that corresponds to the
/// HIPAR errorMessage/status code you specify.
ViStatus _VI_FUNC rssmxv_error_message(ViSession instrSession,
                                       ViStatus  errorCode,
                                       ViChar    errorMessage[])
{
    return rssmxv_utility_error_message( instrSession, errorCode, errorMessage);
}

/// HIFN This function switches ON/OFF various error checkings performed inside of the driver.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR optionChecking/This control switches option checking On or Off.
/// HIPAR rangeChecking/This control enables or disables range checking.
/// HIPAR statusChecking/This control enables or disables instrument state checking
ViStatus _VI_FUNC rssmxv_ConfigureErrorChecking(ViSession instrSession,
                                                ViBoolean optionChecking,
                                                ViBoolean rangeChecking,
                                                ViBoolean statusChecking)
{
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));
    rsSession->optionChecking = optionChecking;
    checkErr(RsCore_SetAttributeViBoolean(instrSession, "", RS_ATTR_QUERY_INSTRUMENT_STATUS, 0, statusChecking));
    checkErr(RsCore_SetAttributeViBoolean(instrSession, "", RS_ATTR_RANGE_CHECK, 0, rangeChecking));

Error:
    return error;
}

/// HIFN  This function clears status.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rssmxv_ClearStatus(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_ClearStatus(instrSession));
    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function returns the ID Query response string.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR IDQueryResponse/Returns the ID Query response string.
ViStatus _VI_FUNC rssmxv_IDQueryResponse(ViSession instrSession,
                                         ViChar    IDQueryResponse[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_QueryViString(instrSession, "*IDN?", 256, IDQueryResponse));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Stops further command processing until all commands sent before
/// HIFN  *WAI have been executed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rssmxv_ProcessAllPreviousCommands(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_WriteInstrData(instrSession, "*WAI"));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the OPC.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR OPC/Queries the OPC.
ViStatus _VI_FUNC rssmxv_QueryOPC(ViSession instrSession,
                                  ViInt32*  OPC)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_QueryViInt32(instrSession, "*OPC?", OPC));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function sets the OPC timeout.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rspwrmeter_init or
/// HIPAR instrSession/rspwrmeter_InitWithOptions function.
/// HIPAR timeout/This control sets the timeout value.
ViStatus _VI_FUNC rssmxv_SetOPCTimeout(ViSession instrSession,
                                       ViUInt32  timeout)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_SetAttributeViInt32(instrSession, NULL, RS_ATTR_OPC_TIMEOUT, 0, (ViInt32)timeout));

Error:
    return error;
}

/// HIFN This function returns the OPC timeout.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.
/// HIPAR timeout/This control returns the timeout value.
ViStatus _VI_FUNC rssmxv_GetOPCTimeout(ViSession instrSession,
                                       ViUInt32* timeout)
{
    ViStatus error = VI_SUCCESS;
    ViInt32  timeoutInt;

    checkErr(RsCore_GetAttributeViInt32(instrSession, NULL, RS_ATTR_OPC_TIMEOUT, 0, &timeoutInt));
    *timeout = (ViUInt32)timeoutInt;

Error:
    return error;
}

/// HIFN This function specifies the minimum timeout value to use (in
/// HIFN milliseconds) when accessing the device associated with the
/// HIFN given session.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.
/// HIPAR VISATimeout/This control sets the timeout value.
ViStatus _VI_FUNC rssmxv_SetVISATimeout(ViSession instrSession,
                                        ViUInt32  VISATimeout)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_SetVisaTimeout(instrSession, VISATimeout));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function returns the minimum timeout value to use (in
/// HIFN milliseconds) when accessing the device associated with the
/// HIFN given session.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.
/// HIPAR VISATimeout/This control gets the timeout value.
ViStatus _VI_FUNC rssmxv_GetVISATimeout(ViSession instrSession,
                                        ViUInt32* VISATimeout)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetVisaTimeout(instrSession, VISATimeout));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function calibrates the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the RsSMxV_init or
/// HIPAR instrSession/RsSMxV_InitWithOptions function.  The handle identifies a
/// HIPAR instrSession/particular instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR timeout/Sets the timeout.
/// HIPAR result/Returns the calibration result.
ViStatus _VI_FUNC rssmxv_Calibrate(ViSession instrSession,
                                   ViInt32   reserved,
                                   ViInt32   timeoutInMs,
                                   ViInt32*  calibrationResult)
{
    ViStatus error = VI_SUCCESS;
    ViUInt32 old_timeout = 0;
             reserved;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_GetOPCTimeout(instrSession, &old_timeout));
    checkErr(rssmxv_SetOPCTimeout(instrSession, timeoutInMs));
    viCheckParm(rssmxv_GetAttributeViInt32(instrSession, NULL, RSSMXV_ATTR_CALIBRATION_ALL, calibrationResult),
            4, "Result");

Error:
    if (old_timeout > 0)
        rssmxv_SetOPCTimeout(instrSession, old_timeout);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the date of the last factory calibration.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the RsSMxV_init or
/// HIPAR instrSession/RsSMxV_InitWithOptions function.  The handle identifies a
/// HIPAR instrSession/particular instrument session.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufferSize/Value parameter.
/// HIPAR calibrationDate/Returns the date of the last factory calibration.
ViStatus _VI_FUNC rssmxv_LastFactoryCalibration(ViSession instrSession,
                                                ViInt32   bufferSize,
                                                ViChar    calibrationDate[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_GetAttributeViString(instrSession, NULL, RSSMXV_ATTR_LAST_FACTORY_CALIBRATION,
            bufferSize, calibrationDate),
            3, "Calibration Date");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  To unlock the user interface for manual operation, use one of the
/// HIFN  following:
/// HIFN
/// HIFN     - On the instrument's keypad or external keyboard, press any key.
/// HIFN     The instrument prompts you to enter the security password for
/// HIFN  unlocking.
/// HIFN
/// HIFN     Note: The character of the first key you pressed is immediately added
/// HIFN  in the input field. Delete the entry before inserting the password.
/// HIFN     Enter the security password 123456.
/// HIFN
/// HIFN     - In remote control mode, send the command SYST:ULOC ENABled to
/// HIFN  release all locks at once.
/// HIFN     Alternatively:
/// HIFN     - Send the command SYST:KLOC OFF to unlock the keyboard and
/// HIFN  touchscreen
/// HIFN     - Send the command SYST:DLOC OFF to release all locks.
/// HIFN
/// HIFN     Via remote control, there is no password required.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the RsSMxV_init or
/// HIPAR instrSession/RsSMxV_InitWithOptions function.  The handle identifies a
/// HIPAR instrSession/particular instrument session.
/// HIPAR userInterface/Locks or unlocks the user interface of the instrument.
ViStatus _VI_FUNC rssmxv_LockUserInterface(ViSession instrSession,
                                           ViInt32   userInterface)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmxv_SetAttributeViInt32(instrSession, "", RSSMXV_ATTR_SYSTEM_USER_INTERFACE_LOCK, userInterface),
            2, "User Interface");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN If TRUE (default after init is FALSE), the driver calls SYST:ERR? automatically in CheckStatus() when Instrument Status Error is detected.
/// HIFN Use the function rssmxv_GetError afterwards to get the detailed information about the instrument error(s).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR autoSystErrQuery/If TRUE (default after init is FALSE), the driver calls SYST:ERR? automatically in CheckStatus() when Instrument Status Error is detected.
ViStatus _VI_FUNC rssmxv_ConfigureAutoSystemErrQuery(ViSession instrSession,
                                                     ViBoolean autoSystErrQuery)
{
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));
    rsSession->autoSystErrQuery = autoSystErrQuery;

Error:
    return error;
}

/// HIFN Session-related mutex switch.
/// HIFN If TRUE (default after init is FALSE), the driver sets a mutual-exclusion mechanism for every driver's hi-level function and attribute access.
/// HIFN Set this value to TRUE if you plan to use one session in more than one thread.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR multiThreadLocking/Session-related mutex switch
ViStatus _VI_FUNC rssmxv_ConfigureMultiThreadLocking(ViSession instrSession,
                                                     ViBoolean multiThreadLocking)
{
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));
    rsSession->multiThreadLocking = multiThreadLocking;

Error:
    return error;
}

/// HIFN This function configures attribute data type mismatch reporting
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR state/Enables/disables data type mismatch reporting.
ViStatus _VI_FUNC rssmxv_ConfigureAttributeDataTypeMismatchReporting(
                            ViSession instrSession,
                            ViBoolean state)
{
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));
    rsSession->reportAttrDataTypeMismatch = state;

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates volatile mode, so that no user data can be written to the
/// HIFN  internal memory permanently.
/// HIFN
/// HIFN     To enable volatile mode, reboot the instrument. Otherwise the change
/// HIFN  has no effect.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the RsSMxV_init or
/// HIPAR instrSession/RsSMxV_InitWithOptions function.  The handle identifies a
/// HIPAR instrSession/particular instrument session.
/// HIPAR password/Current security password.
/// HIPAR memoryProtectionState/Memory protection state.
ViStatus _VI_FUNC rssmxv_SecurityVolatileMode(ViSession instrSession,
                                              ViString  password,
                                              ViBoolean memoryProtectionState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":SYST:SEC:VOLM '%s',%s", password, memoryProtectionState ? "ON" : "OFF");
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function sets the Enable, NTransition, and PTransition bits
/// HIFN of the Main status questionable and operating registers.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR registerOperation/Specifies the operation to perform.
/// HIPAR questionableRegister/This control selects the registers that will be configured.
/// HIPAR enable/This control sets the enable bits of the status register.
/// HIPAR PTransition/This control sets the PTransition bits (edge detectors) of the
/// HIPAR PTransition/status register.
/// HIPAR NTransition/This control sets the NTransition bits (edge detectors) of the
/// HIPAR NTransition/status register.
ViStatus _VI_FUNC rssmxv_SetStatusRegister(ViSession instrSession,
                                           ViInt32   registerOperation,
                                           ViInt32   questionableRegister,
                                           ViInt32   enable,
                                           ViInt32   PTransition,
                                           ViInt32   NTransition)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    switch (registerOperation)
    {
    case RSSMXV_VAL_STAT_REG_PRESET:
        checkErr(rssmxv_SetAttributeViString(instrSession, "", RSSMXV_ATTR_STATUS_PRESET, NULL));
        break;
    case RSSMXV_VAL_STAT_REG_QUESTIONABLE:
        switch (questionableRegister) // NOLINT(hicpp-multiway-paths-covered)
        {
        case RSSMXV_VAL_STAT_REG_MAIN:
            viCheckParm(RsCore_InvalidViInt32Range(instrSession, enable, 0, 65535),
                    4, "Enable");
            viCheckParm(RsCore_InvalidViInt32Range(instrSession, PTransition, 0, 65535),
                    5, "PTransition");
            viCheckParm(RsCore_InvalidViInt32Range(instrSession, NTransition, 0, 65535),
                    6, "NTransition");

            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "STAT:QUES:ENAB %ld;PTR %ld;NTR %ld", enable, PTransition,
                     NTransition);
            checkErr(RsCore_Write(instrSession, cmd));
            break;
        default:
            viCheckParm(RsCore_InvalidViInt32Value(instrSession, registerOperation), 3, "Questionable Operation");
        }
        break;
    case RSSMXV_VAL_STAT_REG_OPERATION:
        viCheckParm(RsCore_InvalidViInt32Range(instrSession, enable, 0, 65535),
                4, "Enable");
        viCheckParm(RsCore_InvalidViInt32Range(instrSession, PTransition, 0, 65535),
                5, "PTransition");
        viCheckParm(RsCore_InvalidViInt32Range(instrSession, NTransition, 0, 65535),
                6, "NTransition");

        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "STAT:OPER:ENAB %ld;PTR %ld;NTR %ld", enable, PTransition, NTransition);
        checkErr(RsCore_Write(instrSession, cmd));
        break;
    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, registerOperation), 2, "Register Operation");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function contains the commands for the querying status
/// HIFN reporting system.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR registerOperation/Specifies the operation to perform.
/// HIPAR questionableRegister/This control selects the registers that will be configured.
/// HIPAR registerPart/Sets the register part.
/// HIPAR registerValue/Returns content of selected register.
ViStatus _VI_FUNC rssmxv_GetStatusRegister(ViSession instrSession,
                                           ViInt32   registerOperation,
                                           ViInt32   questionableRegister,
                                           ViInt32   registerPart,
                                           ViInt32*  registerValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViString statusRegister[] = {"COND", "EVEN"};

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, registerPart, 0, 1),
            4, "Register Part");

    switch (registerOperation)
    {
    case RSSMXV_VAL_STAT_REG_QUESTIONABLE:
        switch (questionableRegister) // NOLINT(hicpp-multiway-paths-covered)
        {
        case RSSMXV_VAL_STAT_REG_MAIN:
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":STAT:QUES:%s?", statusRegister[registerPart]);
            checkErr(RsCore_QueryViInt32(instrSession, cmd, registerValue));
            break;
        default:
            viCheckParm(RsCore_InvalidViInt32Value(instrSession, registerOperation), 3, "Questionable Operation");
        }

        break;
    case RSSMXV_VAL_STAT_REG_OPERATION:
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":STAT:OPER:%s?", statusRegister[registerPart]);
        checkErr(RsCore_QueryViInt32(instrSession, cmd, registerValue));
        break;
    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, registerOperation), 2, "Register Operation");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function retrieves and then clears the IVI error information for
/// HIFN  the session or the current execution thread. One exception exists: If
/// HIFN  the BufferSize parameter is 0, the function does not clear the error
/// HIFN  information. By passing 0 for the buffer size, the caller can ascertain
/// HIFN  the buffer size required to get the entire error description string and
/// HIFN  then call the function again with a sufficiently large buffer.
/// HIFN
/// HIFN     If the user specifies a valid IVI session for the instrSession
/// HIFN  parameter, Get Error retrieves and then clears the error information
/// HIFN  for the session.  If the user passes NULL for the instrSession
/// HIFN  parameter, this function retrieves and then clears the error
/// HIFN  information for the current execution thread.  If the instrSession
/// HIFN  parameter is an invalid session, the function does nothing and returns
/// HIFN  an error. Normally, the error information describes the first error
/// HIFN  that occurred since the user last called rssmxv_GetError or
/// HIFN  rssmxv_ClearError.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a
/// HIPAR instrSession/particular instrument session.
/// HIPAR errorCode/Returns the error code for the session or execution thread.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufferSize/Description parameter.
/// HIPAR description/Returns the error description for the IVI session or execution thread.
/// HIPAR description/ If there is no description, the function returns an empty string.
ViStatus _VI_FUNC rssmxv_GetError(ViSession instrSession,
                                  ViStatus* errorCode,
                                  ViInt32   bufferSize,
                                  ViChar    description[])
{
    ViStatus error = VI_SUCCESS;

    // Lock Session - do not jump to the end, even with invalid instrSession the function continues further
    (void)(RsCore_LockSession(instrSession));

    // Test for nulls and acquire error data
    viCheckParm(RsCore_InvalidNullPointer(instrSession, errorCode), 2, "Null address for Error");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, description), 4, "Null address for Description");

    checkErr(
        RsCore_GetErrorCompleteDescription(instrSession, &rssmxv_utility_error_message, errorCode, bufferSize, description));

Error:
    // Unlock Session
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

ViStatus _VI_FUNC rssmxv_ClearError(ViSession instrSession)
{
    return RsCore_ClearErrorInfo(instrSession);
}

/// HIFN This function writes a user-specified string to the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsscope_init or
/// HIPAR instrSession/rsscope_InitWithOptions function.
/// HIPAR writeBuffer/Pass the string to be written to the instrument.
ViStatus _VI_FUNC rssmxv_WriteInstrData(ViSession instrSession,
                                        ViString  writeBuffer)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    error = RsCore_Write(instrSession, writeBuffer);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function queries the ViBoolean value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.
/// HIPAR command/The query to be sent to the instrument.
/// HIPAR value/Returns the ViBoolean value.
ViStatus _VI_FUNC rssmxv_QueryViBoolean(ViSession  instrSession,
                                        ViString   command,
                                        ViBoolean* value)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidStringLength(instrSession, command, 1, -1),
                2, "Command (null string length)");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

    checkErr(RsCore_QueryViBoolean(instrSession, command, value));

    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function queries the ViInt32 value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.
/// HIPAR command/The query to be sent to the instrument.
/// HIPAR value/Returns the ViInt32 value.
ViStatus _VI_FUNC rssmxv_QueryViInt32(ViSession instrSession,
                                      ViString  command,
                                      ViInt32*  value)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidStringLength(instrSession, command, 1, -1),
                2, "Command (null string length)");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

    checkErr(RsCore_QueryViInt32(instrSession, command, value));

    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function queries the ViReal64 value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.
/// HIPAR command/The query to be sent to the instrument.
/// HIPAR value/Returns the ViReal64 value.
ViStatus _VI_FUNC rssmxv_QueryViReal64(ViSession instrSession,
                                       ViString  command,
                                       ViReal64* value)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidStringLength(instrSession, command, 1, -1),
                2, "Command (null string length)");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

    checkErr(RsCore_QueryViReal64(instrSession, command, value));

    checkErr(rssmxv_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function queries the ViString value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.
/// HIPAR command/The query to be sent to the instrument.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the Value parameter.
/// HIPAR value/Returns the string value.
ViStatus _VI_FUNC rssmxv_QueryViString(ViSession instrSession,
                                       ViString  command,
                                       ViInt32   bufferSize,
                                       ViChar    value[])
{
    ViStatus error = VI_SUCCESS;
    ViChar*  pbuffer = NULL;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidStringLength(instrSession, command, 1, -1),
                2, "Command (null string length)");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

    checkErr(RsCore_QueryViStringUnknownLength(instrSession, command, &pbuffer));

    checkErr(rssmxv_CheckStatus(instrSession));

    checkErr(RsCore_CopyToUserBufferAsciiData(value, bufferSize, pbuffer));

Error:
    if (pbuffer)
        free(pbuffer);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sets the value of a ViInt32 attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsscope_init or
/// HIPAR instrSession/rsscope_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name
/// HIPAR channelName/of the channel on which to set the value of the attribute. If the
/// HIPAR channelName/attribute is not channel-based, then pass NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Pass the value to which you want to set the attribute.
ViStatus _VI_FUNC rssmxv_SetAttributeViInt32(ViSession instrSession,
                                             ViString  repeatedCapabilityName,
                                             ViAttr    attributeID,
                                             ViInt32   attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_SetAttributeViInt32(instrSession, repeatedCapabilityName, attributeID, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sets the value of a ViInt64 attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsscope_init or
/// HIPAR instrSession/rsscope_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name
/// HIPAR channelName/of the channel on which to set the value of the attribute. If the
/// HIPAR channelName/attribute is not channel-based, then pass NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Pass the value to which you want to set the attribute.
ViStatus _VI_FUNC rssmxv_SetAttributeViInt64(ViSession instrSession,
                                             ViString  repeatedCapabilityName,
                                             ViAttr    attributeID,
                                             ViInt64   attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_SetAttributeViInt64(instrSession, repeatedCapabilityName, attributeID, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sets the value of a ViReal64 attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsscope_init or
/// HIPAR instrSession/rsscope_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name
/// HIPAR channelName/of the channel on which to set the value of the attribute. If the
/// HIPAR channelName/attribute is not channel-based, then pass NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Pass the value to which you want to set the attribute.
ViStatus _VI_FUNC rssmxv_SetAttributeViReal64(ViSession instrSession,
                                              ViString  repeatedCapabilityName,
                                              ViAttr    attributeID,
                                              ViReal64  attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_SetAttributeViReal64(instrSession, repeatedCapabilityName, attributeID, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sets the value of a ViString attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsscope_init or
/// HIPAR instrSession/rsscope_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name
/// HIPAR channelName/of the channel on which to set the value of the attribute. If the
/// HIPAR channelName/attribute is not channel-based, then pass NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Pass the value to which you want to set the attribute.
ViStatus _VI_FUNC rssmxv_SetAttributeViString(ViSession instrSession,
                                              ViString  repeatedCapabilityName,
                                              ViAttr    attributeID,
                                              ViString  attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_SetAttributeViStringOrRawString(instrSession, repeatedCapabilityName, attributeID, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sets the value of a ViBoolean attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsscope_init or
/// HIPAR instrSession/rsscope_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name
/// HIPAR channelName/of the channel on which to set the value of the attribute. If the
/// HIPAR channelName/attribute is not channel-based, then pass NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Pass the value to which you want to set the attribute.
ViStatus _VI_FUNC rssmxv_SetAttributeViBoolean(ViSession instrSession,
                                               ViString  repeatedCapabilityName,
                                               ViAttr    attributeID,
                                               ViBoolean attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_SetAttributeViBoolean(instrSession, repeatedCapabilityName, attributeID, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the value of a ViInt32 attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsscope_init or
/// HIPAR instrSession/rsscope_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name
/// HIPAR channelName/of the channel on which to obtain the value of the attribute. If the
/// HIPAR channelName/attribute is not channel-based, then pass NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Returns the current value of the attribute.  Pass the address of a
/// HIPAR value/ViInt32 variable.
ViStatus _VI_FUNC rssmxv_GetAttributeViInt32(ViSession instrSession,
                                             ViString  repeatedCapabilityName,
                                             ViAttr    attributeID,
                                             ViInt32*  attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);
    error = RsCore_GetAttributeViInt32(instrSession, repeatedCapabilityName, attributeID, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the value of a ViInt64 attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsscope_init or
/// HIPAR instrSession/rsscope_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name
/// HIPAR channelName/of the channel on which to obtain the value of the attribute. If the
/// HIPAR channelName/attribute is not channel-based, then pass NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Returns the current value of the attribute.  Pass the address of a
/// HIPAR value/ViInt64 variable.
ViStatus _VI_FUNC rssmxv_GetAttributeViInt64(ViSession instrSession,
                                             ViString  repeatedCapabilityName,
                                             ViAttr    attributeID,
                                             ViInt64*  attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_GetAttributeViInt64(instrSession, repeatedCapabilityName, attributeID, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the value of a ViReal64 attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsscope_init or
/// HIPAR instrSession/rsscope_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name
/// HIPAR channelName/of the channel on which to obtain the value of the attribute. If the
/// HIPAR channelName/attribute is not channel-based, then pass NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Returns the current value of the attribute.  Pass the address of a
/// HIPAR value/ViReal64 variable.
ViStatus _VI_FUNC rssmxv_GetAttributeViReal64(ViSession instrSession,
                                              ViString  repeatedCapabilityName,
                                              ViAttr    attributeID,
                                              ViReal64* attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_GetAttributeViReal64(instrSession, repeatedCapabilityName, attributeID, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the value of a ViString attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsscope_init or
/// HIPAR instrSession/rsscope_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name
/// HIPAR channelName/of the channel on which to obtain the value of the attribute. If the
/// HIPAR channelName/attribute is not channel-based, then pass NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR bufSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufSize/Attribute Value parameter.
/// HIPAR value/The buffer in which the function returns the current value of the
/// HIPAR value/attribute.  The buffer must be of type ViChar and have at least as many
/// HIPAR value/bytes as indicated in the Buffer Size parameter.
ViStatus _VI_FUNC rssmxv_GetAttributeViString(ViSession instrSession,
                                              ViString  repeatedCapabilityName,
                                              ViAttr    attributeID,
                                              ViInt32   bufferSize,
                                              ViChar    attributeValue[])
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_GetAttributeViStringOrRawString(instrSession, repeatedCapabilityName, attributeID, RS_VAL_DIRECT_USER_CALL, bufferSize,
        attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the value of a ViBoolean attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsscope_init or
/// HIPAR instrSession/rsscope_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name
/// HIPAR channelName/of the channel on which to obtain the value of the attribute. If the
/// HIPAR channelName/attribute is not channel-based, then pass NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Returns the current value of the attribute.  Pass the address of a
/// HIPAR value/ViBoolean variable.
ViStatus _VI_FUNC rssmxv_GetAttributeViBoolean(ViSession  instrSession,
                                               ViString   repeatedCapabilityName,
                                               ViAttr     attributeID,
                                               ViBoolean* attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_GetAttributeViBoolean(instrSession, repeatedCapabilityName, attributeID, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the value of a ViBoolean attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsscope_init or
/// HIPAR instrSession/rsscope_InitWithOptions function.
/// HIPAR repeatedCapability/If the attribute requires repeated capabilities to be specified,
/// HIPAR repeatedCapability/this parameter specifies one or more comma-separated repeated
/// HIPAR repeatedCapability/capability identifiers on which to set the value of the
/// HIPAR repeatedCapability/attribute. If the attribute does not contain any repeated
/// HIPAR repeatedCapability/capabilities, then pass NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufferSize/Attribute Value parameter.
/// HIPAR attributeValue/The buffer in which the function returns the current value
/// HIPAR attributeValue/ of the attribute.  The buffer must be of type ViChar and
/// HIPAR attributeValue/have at least as many bytes as indicated in the Buffer Size parameter.
/// HIPAR responseLength/The length in bytes of the response read from the instrument. If
/// HIPAR responseLength/Response Length > allocated Buffer Size, some data from the instrument
/// HIPAR responseLength/ was lost; resize your buffer to at least Response Length and call
/// HIPAR responseLength/again to capture the missing data from the instrument.
ViStatus _VI_FUNC rssmxv_GetAttributeViStringWithRealLen(ViSession instrSession,
                                                         ViString  repeatedCapabilityName,
                                                         ViAttr    attributeID,
                                                         ViInt32   bufferSize,
                                                         ViChar    attributeValue[],
                                                         ViInt32*  responseLength)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_GetAttributeViStringWithRealLen(instrSession, repeatedCapabilityName, attributeID, RS_VAL_DIRECT_USER_CALL, bufferSize, attributeValue, responseLength);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function queries the value of a ViBoolean attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsscope_init or
/// HIPAR instrSession/rsscope_InitWithOptions function.
/// HIPAR repeatedCapability/If the attribute requires repeated capabilities to be specified,
/// HIPAR repeatedCapability/this parameter specifies one or more comma-separated repeated
/// HIPAR repeatedCapability/capability identifiers on which to set the value of the
/// HIPAR repeatedCapability/attribute. If the attribute does not contain any repeated
/// HIPAR repeatedCapability/capabilities, then pass NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufferSize/Attribute Value parameter.
/// HIPAR attributeValue/The buffer in which the function returns the current value
/// HIPAR attributeValue/ of the attribute.  The buffer must be of type ViChar and
/// HIPAR attributeValue/have at least as many bytes as indicated in the Buffer Size parameter.
/// HIPAR responseLength/The length in bytes of the response read from the instrument. If
/// HIPAR responseLength/Response Length > allocated Buffer Size, some data from the instrument
/// HIPAR responseLength/ was lost; resize your buffer to at least Response Length and call
/// HIPAR responseLength/again to capture the missing data from the instrument.
ViStatus _VI_FUNC rssmxv_GetAttributeRawStringWithRealLen(ViSession instrSession,
                                                          ViString  repeatedCapabilityName,
                                                          ViAttr    attributeID,
                                                          ViInt32   bufferSize,
                                                          ViChar    attributeValue[],
                                                          ViInt32*  responseLength)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_GetAttributeViRawStringWithRealLen(instrSession, repeatedCapabilityName, attributeID, RS_VAL_DIRECT_USER_CALL, bufferSize, attributeValue, responseLength);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Function used by Hi-level functions to obtain a repCap name from:
/// HIFN - attributeID
/// HIFN - repCapNameID
/// HIFN - 0-based index in the repCapNames
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsscope_init or
/// HIPAR instrSession/rsscope_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR repCapNameId/RepCap Name ID.
/// HIPAR index/Zero based index in the repCapNames.
/// HIPAR bufferSize/Pass the number of bytes in the string you allocate for the repCapName.
/// HIPAR repCapName/String returning RepCap name
ViStatus _VI_FUNC rssmxv_GetAttributeRepCapName(ViSession instrSession,
                                                ViAttr    attributeId,
                                                ViString  repCapNameId,
                                                ViInt32   index,
                                                ViInt32   bufferSize,
                                                ViChar    repCapName[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, attributeId, repCapNameId, index, bufferSize, repCapName));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
* Function: rssmxv_GetAttributeRepeatedCapabilityIds
* Purpose:  This function returns the repeated capability id(s) that
*           belongs to the attribute you specify. More then one id is listed
*           in comma separated string.
*****************************************************************************/
ViStatus _VI_FUNC rssmxv_GetAttributeRepeatedCapabilityIds(ViSession instrSession,
                                                           ViAttr    attributeId,
                                                           ViInt32   bufferSize,
                                                           ViChar    repeatedCapabilityIds[])
{
    ViStatus error = VI_SUCCESS;

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, bufferSize, 1, RS_MAX_SHORT_MESSAGE_BUF_SIZE),
            3, "Buffer Size");

    checkErr(RsCore_GetAttributeRepCapNameIds(instrSession, attributeId, bufferSize, repeatedCapabilityIds));

Error:
    return error;
}

/// HIFN This function returns the repeated capability name(s) that
/// HIFN belongs to the attribute and single repeated capability id you
/// HIFN may specify. More then one name is listed in comma separated
/// HIFN string.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsscope_init or
/// HIPAR instrSession/rsscope_InitWithOptions function.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR repeatedCapabilityId/If the attribute applies to a repeated capability such as a trace, this parameter defines the Id of the repeated capability on which to query repeated capability id name(s).
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the Repeated Capability Id Name(s) parameter.
/// HIPAR repeatedCapabilityIdNames/The buffer in which the function returns the repeated capability id name(s) belonging to the attribute.
ViStatus _VI_FUNC rssmxv_GetAttributeRepeatedCapabilityIdNames(
                            ViSession instrSession,
                            ViAttr    attributeId,
                            ViString  repeatedCapabilityId,
                            ViInt32   bufferSize,
                            ViChar    repeatedCapabilityIdNames[])
{
    ViStatus error = VI_SUCCESS;

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, bufferSize, 1, RS_MAX_SHORT_MESSAGE_BUF_SIZE),
            4, "Buffer Size");

    checkErr(RsCore_GetAttributeRepCapNamesAll(instrSession,
        attributeId,
        repeatedCapabilityId,
        bufferSize,
        repeatedCapabilityIdNames));

Error:
    return error;
}

/// HIFN  This function sends a command to trigger the RF signal generator.
/// HIFN  Call this function if you set a trigger source to a software trigger
/// HIFN  value.  Below is a list of attributes and functions which can set the
/// HIFN  trigger source to a software trigger.
/// HIFN  driver functions.  The sequence performs one operation.  You use the
/// HIFN  low-level functions to optimize one or more aspects of interaction with
/// HIFN  the instrument.  If you want to check the instrument status, call the
/// HIFN  rssmxv_error_query function at the conclusion of the sequence.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a
/// HIPAR instrSession/particular instrument session.
ViStatus _VI_FUNC rssmxv_SendSoftwareTrigger(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmxv_SetAttributeViString(instrSession, "", RSSMXV_ATTR_INIT_SW_TRIGGER, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function performs the following operations:
/// HIFN
/// HIFN     - Closes the instrument I/O session.
/// HIFN
/// HIFN     - Destroys the instrument driver session and all of its attributes.
/// HIFN
/// HIFN     - Deallocates any memory resources the driver uses.
/// HIFN
/// HIFN     Notes:
/// HIFN
/// HIFN     (1) You must unlock the session before calling rssmxv_close.
/// HIFN
/// HIFN     (2) After calling rssmxv_close, you cannot use the instrument
/// HIFN  driver again until you call rssmxv_init or
/// HIFN  rssmxv_InitWithOptions.
/// HIFN
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmxv_init or
/// HIPAR instrSession/rssmxv_InitWithOptions function.  The handle identifies a
/// HIPAR instrSession/particular instrument session.
ViStatus _VI_FUNC rssmxv_close(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_ViClose(instrSession));

Error:
    (void)RsCore_Dispose(instrSession);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}
